import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiAdvisories } from "../../structures/IApiAdvisories";
import { global_minus_advisory } from "../../structures/global_minus_advisory";
/**
 * List global security advisories.
 * Lists all global security advisories that match the specified parameters. If no other parameters are defined, the request will return only GitHub-reviewed advisories that are not malware.
 *
 * By default, all responses will exclude advisories for malware, because malware are not standard vulnerabilities. To list advisories for malware, you must include the `type` parameter in your request, with the value `malware`. For more information about the different types of security advisories, see "[About the GitHub Advisory database](https://docs.github.com/code-security/security-advisories/global-security-advisories/about-the-github-advisory-database#about-types-of-security-advisories)."
 *
 * @tag security-advisories
 * @path advisories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiAdvisories.GetHeader;
    type Query = IApiAdvisories.GetQuery;
    type Output = global_minus_advisory[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/advisories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => global_minus_advisory[];
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
/**
 * Get a global security advisory.
 * Gets a global security advisory using its GitHub Security Advisory (GHSA) identifier.
 *
 * @tag security-advisories
 * @path advisories/:ghsa_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByGhsa_id(connection: IConnection<getByGhsa_id.Headers>, ghsa_id: string): Promise<getByGhsa_id.Output>;
export declare namespace getByGhsa_id {
    type Headers = IApiAdvisories.GetHeader;
    type Output = global_minus_advisory;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/advisories/:ghsa_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (ghsa_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => global_minus_advisory;
    const simulate: (connection: IConnection<getByGhsa_id.Headers>, ghsa_id: string) => Output;
}
