import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiGistsComments } from "../../../structures/IApiGistsComments";
import { body } from "../../../structures/body";
import { gist_minus_comment } from "../../../structures/gist_minus_comment";
/**
 * List gist comments.
 * Lists the comments on a gist.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw markdown. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github.base64+json`**: Returns the base64-encoded contents. This can be useful if your gist contains any invalid UTF-8 sequences.
 *
 * @tag gists
 * @path gists/:gist_id/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByGist_id(connection: IConnection<getByGist_id.Headers>, gist_id: string): Promise<getByGist_id.Output>;
export declare namespace getByGist_id {
    type Headers = IApiGistsComments.GetHeader;
    type Output = gist_minus_comment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/gists/:gist_id/comments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gist_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gist_minus_comment[];
    const simulate: (connection: IConnection<getByGist_id.Headers>, gist_id: string) => Output;
}
/**
 * Create a gist comment.
 * Creates a comment on a gist.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw markdown. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github.base64+json`**: Returns the base64-encoded contents. This can be useful if your gist contains any invalid UTF-8 sequences.
 *
 * @tag gists
 * @path gists/:gist_id/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByGist_id(connection: IConnection<postByGist_id.Headers>, gist_id: string, body: postByGist_id.Input): Promise<postByGist_id.Output>;
export declare namespace postByGist_id {
    type Headers = IApiGistsComments.PostHeader;
    type Input = body;
    type Output = gist_minus_comment;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/gists/:gist_id/comments";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gist_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gist_minus_comment;
    const simulate: (connection: IConnection<postByGist_id.Headers>, gist_id: string, body: postByGist_id.Input) => Output;
}
/**
 * Get a gist comment.
 * Gets a comment on a gist.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw markdown. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github.base64+json`**: Returns the base64-encoded contents. This can be useful if your gist contains any invalid UTF-8 sequences.
 *
 * @tag gists
 * @path gists/:gist_id/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByGist_idAndComment_id(connection: IConnection<getByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string): Promise<getByGist_idAndComment_id.Output>;
export declare namespace getByGist_idAndComment_id {
    type Headers = IApiGistsComments.GetHeader;
    type Output = gist_minus_comment;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/gists/:gist_id/comments/:comment_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gist_id: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gist_minus_comment;
    const simulate: (connection: IConnection<getByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string) => Output;
}
/**
 * Update a gist comment.
 * Updates a comment on a gist.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw markdown. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github.base64+json`**: Returns the base64-encoded contents. This can be useful if your gist contains any invalid UTF-8 sequences.
 *
 * @tag gists
 * @path gists/:gist_id/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByGist_idAndComment_id(connection: IConnection<patchByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string, body: patchByGist_idAndComment_id.Input): Promise<patchByGist_idAndComment_id.Output>;
export declare namespace patchByGist_idAndComment_id {
    type Headers = IApiGistsComments.PatchHeader;
    type Input = body;
    type Output = gist_minus_comment;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/gists/:gist_id/comments/:comment_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gist_id: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gist_minus_comment;
    const simulate: (connection: IConnection<patchByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string, body: patchByGist_idAndComment_id.Input) => Output;
}
/**
 * @tag gists
 * @path gists/:gist_id/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByGist_idAndComment_id(connection: IConnection<eraseByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string): Promise<void>;
export declare namespace eraseByGist_idAndComment_id {
    type Headers = IApiGistsComments.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/gists/:gist_id/comments/:comment_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gist_id: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByGist_idAndComment_id.Headers>, gist_id: string, comment_id: string) => void;
}
