import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { gitignore_minus_template } from "../../../structures/gitignore_minus_template";
/**
 * Get all gitignore templates.
 * List all templates available to pass as an option when [creating a repository](https://docs.github.com/rest/repos/repos#create-a-repository-for-the-authenticated-user).
 *
 * @tag gitignore
 * @path gitignore/templates
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection): Promise<get.Output>;
export declare namespace get {
    type Output = string[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/gitignore/templates";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => string[];
    const simulate: (connection: IConnection) => Output;
}
/**
 * Get a gitignore template.
 * Get the content of a gitignore template.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw .gitignore contents.
 *
 * @tag gitignore
 * @path gitignore/templates/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByName(connection: IConnection, name: string): Promise<getByName.Output>;
export declare namespace getByName {
    type Output = gitignore_minus_template;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/gitignore/templates/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gitignore_minus_template;
    const simulate: (connection: IConnection, name: string) => Output;
}
