import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsPermissionsWorkflow } from "../../../../../structures/IApiOrgsActionsPermissionsWorkflow";
import { actions_minus_get_minus_default_minus_workflow_minus_permissions } from "../../../../../structures/actions_minus_get_minus_default_minus_workflow_minus_permissions";
import { actions_minus_set_minus_default_minus_workflow_minus_permissions } from "../../../../../structures/actions_minus_set_minus_default_minus_workflow_minus_permissions";
/**
 * Get default workflow permissions for an organization.
 * Gets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an organization,
 * as well as whether GitHub Actions can submit approving pull request reviews. For more information, see
 * "[Setting the permissions of the GITHUB_TOKEN for your organization](https://docs.github.com/organizations/managing-organization-settings/disabling-or-limiting-github-actions-for-your-organization#setting-the-permissions-of-the-github_token-for-your-organization)."
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/workflow
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsPermissionsWorkflow.GetHeader;
    type Output = actions_minus_get_minus_default_minus_workflow_minus_permissions;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/permissions/workflow";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_get_minus_default_minus_workflow_minus_permissions;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Set default workflow permissions for an organization.
 * Sets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an organization, and sets if GitHub Actions
 * can submit approving pull request reviews. For more information, see
 * "[Setting the permissions of the GITHUB_TOKEN for your organization](https://docs.github.com/organizations/managing-organization-settings/disabling-or-limiting-github-actions-for-your-organization#setting-the-permissions-of-the-github_token-for-your-organization)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/workflow
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrg(connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input): Promise<void>;
export declare namespace putByOrg {
    type Headers = IApiOrgsActionsPermissionsWorkflow.PutHeader;
    type Input = actions_minus_set_minus_default_minus_workflow_minus_permissions;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/permissions/workflow";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input) => void;
}
