import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsVariables } from "../../../../structures/IApiOrgsActionsVariables";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { organization_minus_actions_minus_variable } from "../../../../structures/organization_minus_actions_minus_variable";
import { response } from "../../../../structures/response";
export * as repositories from "./repositories";
/**
 * List organization variables.
 * Lists all organization variables.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsVariables.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/variables";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Create an organization variable.
 * Creates an organization variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsActionsVariables.PostHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/actions/variables";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => Output;
}
/**
 * Get an organization variable.
 * Gets a specific variable in an organization.
 *
 * The authenticated user must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndName(connection: IConnection<getByOrgAndName.Headers>, org: string, name: string): Promise<getByOrgAndName.Output>;
export declare namespace getByOrgAndName {
    type Headers = IApiOrgsActionsVariables.GetHeader;
    type Output = organization_minus_actions_minus_variable;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => organization_minus_actions_minus_variable;
    const simulate: (connection: IConnection<getByOrgAndName.Headers>, org: string, name: string) => Output;
}
/**
 * Update an organization variable.
 * Updates an organization variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrgAndName(connection: IConnection<patchByOrgAndName.Headers>, org: string, name: string, body: patchByOrgAndName.Input): Promise<void>;
export declare namespace patchByOrgAndName {
    type Headers = IApiOrgsActionsVariables.PatchHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/actions/variables/:name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<patchByOrgAndName.Headers>, org: string, name: string, body: patchByOrgAndName.Input) => void;
}
/**
 * Delete an organization variable.
 * Deletes an organization variable using the variable name.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndName(connection: IConnection<eraseByOrgAndName.Headers>, org: string, name: string): Promise<void>;
export declare namespace eraseByOrgAndName {
    type Headers = IApiOrgsActionsVariables.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndName.Headers>, org: string, name: string) => void;
}
