import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsCodeSecurityConfigurations } from "../../../../structures/IApiOrgsCodeSecurityConfigurations";
import { body } from "../../../../structures/body";
import { code_minus_security_minus_configuration } from "../../../../structures/code_minus_security_minus_configuration";
export * as defaults from "./defaults";
export * as detach from "./detach";
export * as attach from "./attach";
export * as repositories from "./repositories";
/**
 * Get code security configurations for an organization.
 * Lists all code security configurations available in an organization.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsCodeSecurityConfigurations.GetHeader;
    type Query = IApiOrgsCodeSecurityConfigurations.GetQuery;
    type Output = code_minus_security_minus_configuration[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/code-security/configurations";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_security_minus_configuration[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Create a code security configuration.
 * Creates a code security configuration in an organization.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsCodeSecurityConfigurations.PostHeader;
    type Input = body;
    type Output = code_minus_security_minus_configuration;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/code-security/configurations";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_security_minus_configuration;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => Output;
}
/**
 * Get a code security configuration.
 * Gets a code security configuration available in an organization.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations/:configuration_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndConfiguration_id(connection: IConnection<getByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string): Promise<getByOrgAndConfiguration_id.Output>;
export declare namespace getByOrgAndConfiguration_id {
    type Headers = IApiOrgsCodeSecurityConfigurations.GetHeader;
    type Output = code_minus_security_minus_configuration;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/code-security/configurations/:configuration_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, configuration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_security_minus_configuration;
    const simulate: (connection: IConnection<getByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string) => Output;
}
/**
 * Update a code security configuration.
 * Updates a code security configuration in an organization.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations/:configuration_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrgAndConfiguration_id(connection: IConnection<patchByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string, body: patchByOrgAndConfiguration_id.Input): Promise<patchByOrgAndConfiguration_id.Output>;
export declare namespace patchByOrgAndConfiguration_id {
    type Headers = IApiOrgsCodeSecurityConfigurations.PatchHeader;
    type Input = body;
    type Output = code_minus_security_minus_configuration;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/code-security/configurations/:configuration_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, configuration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_security_minus_configuration;
    const simulate: (connection: IConnection<patchByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string, body: patchByOrgAndConfiguration_id.Input) => Output;
}
/**
 * Delete a code security configuration.
 * Deletes the desired code security configuration from an organization.
 * Repositories attached to the configuration will retain their settings but will no longer be associated with
 * the configuration.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations/:configuration_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndConfiguration_id(connection: IConnection<eraseByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string): Promise<void>;
export declare namespace eraseByOrgAndConfiguration_id {
    type Headers = IApiOrgsCodeSecurityConfigurations.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/code-security/configurations/:configuration_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, configuration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string) => void;
}
