import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsCodespacesAccessSelectedUsers } from "../../../../../structures/IApiOrgsCodespacesAccessSelectedUsers";
import { body } from "../../../../../structures/body";
/**
 * Add users to Codespaces access for an organization.
 * Codespaces for the specified users will be billed to the organization.
 *
 * To use this endpoint, the access settings for the organization must be set to `selected_members`.
 * For information on how to change this setting, see "[Manage access control for organization codespaces](https://docs.github.com/rest/codespaces/organizations#manage-access-control-for-organization-codespaces)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @deprecated
 * @path orgs/:org/codespaces/access/selected_users
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<void>;
export declare namespace postByOrg {
    type Headers = IApiOrgsCodespacesAccessSelectedUsers.PostHeader;
    type Input = body;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/codespaces/access/selected_users";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => void;
}
/**
 * Remove users from Codespaces access for an organization.
 * Codespaces for the specified users will no longer be billed to the organization.
 *
 * To use this endpoint, the access settings for the organization must be set to `selected_members`.
 * For information on how to change this setting, see "[Manage access control for organization codespaces](https://docs.github.com/rest/codespaces/organizations#manage-access-control-for-organization-codespaces)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @deprecated
 * @path orgs/:org/codespaces/access/selected_users
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrg(connection: IConnection<eraseByOrg.Headers>, org: string, body: eraseByOrg.Input): Promise<void>;
export declare namespace eraseByOrg {
    type Headers = IApiOrgsCodespacesAccessSelectedUsers.DeleteHeader;
    type Input = body;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/codespaces/access/selected_users";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrg.Headers>, org: string, body: eraseByOrg.Input) => void;
}
