import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiOrgsCodespacesSecretsRepositories } from "../../../../../structures/IApiOrgsCodespacesSecretsRepositories";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List selected repositories for an organization secret.
 * Lists all repositories that have been selected when the `visibility`
 * for repository access to a secret is set to `selected`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @path orgs/:org/codespaces/secrets/:secret_name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndSecret_name(connection: IConnection<getByOrgAndSecret_name.Headers>, org: string, secret_name: string): Promise<getByOrgAndSecret_name.Output>;
export declare namespace getByOrgAndSecret_name {
    type Headers = IApiOrgsCodespacesSecretsRepositories.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/codespaces/secrets/:secret_name/repositories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrgAndSecret_name.Headers>, org: string, secret_name: string) => Output;
}
/**
 * Set selected repositories for an organization secret.
 * Replaces all repositories for an organization development environment secret when the `visibility`
 * for repository access is set to `selected`. The visibility is set when you [Create
 * or update an organization secret](https://docs.github.com/rest/codespaces/organization-secrets#create-or-update-an-organization-secret).
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @path orgs/:org/codespaces/secrets/:secret_name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndSecret_name(connection: IConnection<putByOrgAndSecret_name.Headers>, org: string, secret_name: string, body: putByOrgAndSecret_name.Input): Promise<void>;
export declare namespace putByOrgAndSecret_name {
    type Headers = IApiOrgsCodespacesSecretsRepositories.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/codespaces/secrets/:secret_name/repositories";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndSecret_name.Headers>, org: string, secret_name: string, body: putByOrgAndSecret_name.Input) => void;
}
/**
 * Add selected repository to an organization secret.
 * Adds a repository to an organization development environment secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/codespaces/organization-secrets#create-or-update-an-organization-secret).
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @path orgs/:org/codespaces/secrets/:secret_name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndSecret_nameAndRepository_id(connection: IConnection<putByOrgAndSecret_nameAndRepository_id.Headers>, org: string, secret_name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace putByOrgAndSecret_nameAndRepository_id {
    type Headers = IApiOrgsCodespacesSecretsRepositories.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/codespaces/secrets/:secret_name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndSecret_nameAndRepository_id.Headers>, org: string, secret_name: string, repository_id: number & tags.Type<"int32">) => void;
}
/**
 * Remove selected repository from an organization secret.
 * Removes a repository from an organization development environment secret when the `visibility`
 * for repository access is set to `selected`. The visibility is set when you [Create
 * or update an organization secret](https://docs.github.com/rest/codespaces/organization-secrets#create-or-update-an-organization-secret).
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag codespaces
 * @path orgs/:org/codespaces/secrets/:secret_name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndSecret_nameAndRepository_id(connection: IConnection<eraseByOrgAndSecret_nameAndRepository_id.Headers>, org: string, secret_name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace eraseByOrgAndSecret_nameAndRepository_id {
    type Headers = IApiOrgsCodespacesSecretsRepositories.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/codespaces/secrets/:secret_name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndSecret_nameAndRepository_id.Headers>, org: string, secret_name: string, repository_id: number & tags.Type<"int32">) => void;
}
