import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsHooksConfig } from "../../../../structures/IApiOrgsHooksConfig";
import { body } from "../../../../structures/body";
import { webhook_minus_config } from "../../../../structures/webhook_minus_config";
/**
 * Get a webhook configuration for an organization.
 * Returns the webhook configuration for an organization. To get more information about the webhook, including the `active` state and `events`, use "[Get an organization webhook ](/rest/orgs/webhooks#get-an-organization-webhook)."
 *
 * You must be an organization owner to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need `admin:org_hook` scope. OAuth apps cannot list, view, or edit
 * webhooks that they did not create and users cannot list, view, or edit webhooks that were created by OAuth apps.
 *
 * @tag orgs
 * @path orgs/:org/hooks/:hook_id/config
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndHook_id(connection: IConnection<getByOrgAndHook_id.Headers>, org: string, hook_id: string): Promise<getByOrgAndHook_id.Output>;
export declare namespace getByOrgAndHook_id {
    type Headers = IApiOrgsHooksConfig.GetHeader;
    type Output = webhook_minus_config;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/hooks/:hook_id/config";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => webhook_minus_config;
    const simulate: (connection: IConnection<getByOrgAndHook_id.Headers>, org: string, hook_id: string) => Output;
}
/**
 * Update a webhook configuration for an organization.
 * Updates the webhook configuration for an organization. To update more information about the webhook, including the `active` state and `events`, use "[Update an organization webhook ](/rest/orgs/webhooks#update-an-organization-webhook)."
 *
 * You must be an organization owner to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need `admin:org_hook` scope. OAuth apps cannot list, view, or edit
 * webhooks that they did not create and users cannot list, view, or edit webhooks that were created by OAuth apps.
 *
 * @tag orgs
 * @path orgs/:org/hooks/:hook_id/config
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrgAndHook_id(connection: IConnection<patchByOrgAndHook_id.Headers>, org: string, hook_id: string, body: patchByOrgAndHook_id.Input): Promise<patchByOrgAndHook_id.Output>;
export declare namespace patchByOrgAndHook_id {
    type Headers = IApiOrgsHooksConfig.PatchHeader;
    type Input = body;
    type Output = webhook_minus_config;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/hooks/:hook_id/config";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => webhook_minus_config;
    const simulate: (connection: IConnection<patchByOrgAndHook_id.Headers>, org: string, hook_id: string, body: patchByOrgAndHook_id.Input) => Output;
}
