import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsHooksDeliveries } from "../../../../structures/IApiOrgsHooksDeliveries";
import { hook_minus_delivery } from "../../../../structures/hook_minus_delivery";
import { hook_minus_delivery_minus_item } from "../../../../structures/hook_minus_delivery_minus_item";
export * as attempts from "./attempts";
/**
 * List deliveries for an organization webhook.
 * Returns a list of webhook deliveries for a webhook configured in an organization.
 *
 * You must be an organization owner to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need `admin:org_hook` scope. OAuth apps cannot list, view, or edit
 * webhooks that they did not create and users cannot list, view, or edit webhooks that were created by OAuth apps.
 *
 * @tag orgs
 * @path orgs/:org/hooks/:hook_id/deliveries
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndHook_id(connection: IConnection<getByOrgAndHook_id.Headers>, org: string, hook_id: string, query: getByOrgAndHook_id.Query): Promise<getByOrgAndHook_id.Output>;
export declare namespace getByOrgAndHook_id {
    type Headers = IApiOrgsHooksDeliveries.GetHeader;
    type Query = IApiOrgsHooksDeliveries.GetQuery;
    type Output = hook_minus_delivery_minus_item[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/hooks/:hook_id/deliveries";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, hook_id: string, query: getByOrgAndHook_id.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook_minus_delivery_minus_item[];
    const simulate: (connection: IConnection<getByOrgAndHook_id.Headers>, org: string, hook_id: string, query: getByOrgAndHook_id.Query) => Output;
}
/**
 * Get a webhook delivery for an organization webhook.
 * Returns a delivery for a webhook configured in an organization.
 *
 * You must be an organization owner to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need `admin:org_hook` scope. OAuth apps cannot list, view, or edit
 * webhooks that they did not create and users cannot list, view, or edit webhooks that were created by OAuth apps.
 *
 * @tag orgs
 * @path orgs/:org/hooks/:hook_id/deliveries/:delivery_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndHook_idAndDelivery_id(connection: IConnection<getByOrgAndHook_idAndDelivery_id.Headers>, org: string, hook_id: string, delivery_id: string): Promise<getByOrgAndHook_idAndDelivery_id.Output>;
export declare namespace getByOrgAndHook_idAndDelivery_id {
    type Headers = IApiOrgsHooksDeliveries.GetHeader;
    type Output = hook_minus_delivery;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/hooks/:hook_id/deliveries/:delivery_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, hook_id: string, delivery_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook_minus_delivery;
    const simulate: (connection: IConnection<getByOrgAndHook_idAndDelivery_id.Headers>, org: string, hook_id: string, delivery_id: string) => Output;
}
