import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsOrganizationRolesTeams } from "../../../../structures/IApiOrgsOrganizationRolesTeams";
import { team_minus_role_minus_assignment } from "../../../../structures/team_minus_role_minus_assignment";
/**
 * Remove all organization roles for a team.
 * Removes all assigned organization roles from a team. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/teams/:team_slug
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slug(connection: IConnection<eraseByOrgAndTeam_slug.Headers>, org: string, team_slug: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slug {
    type Headers = IApiOrgsOrganizationRolesTeams.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/organization-roles/teams/:team_slug";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slug.Headers>, org: string, team_slug: string) => void;
}
/**
 * Assign an organization role to a team.
 * Assigns an organization role to a team in an organization. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/teams/:team_slug/:role_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndTeam_slugAndRole_id(connection: IConnection<putByOrgAndTeam_slugAndRole_id.Headers>, org: string, team_slug: string, role_id: string): Promise<void>;
export declare namespace putByOrgAndTeam_slugAndRole_id {
    type Headers = IApiOrgsOrganizationRolesTeams.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/organization-roles/teams/:team_slug/:role_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndTeam_slugAndRole_id.Headers>, org: string, team_slug: string, role_id: string) => void;
}
/**
 * Remove an organization role from a team.
 * Removes an organization role from a team. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/teams/:team_slug/:role_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndRole_id(connection: IConnection<eraseByOrgAndTeam_slugAndRole_id.Headers>, org: string, team_slug: string, role_id: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndRole_id {
    type Headers = IApiOrgsOrganizationRolesTeams.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/organization-roles/teams/:team_slug/:role_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndRole_id.Headers>, org: string, team_slug: string, role_id: string) => void;
}
/**
 * List teams that are assigned to an organization role.
 * Lists the teams that are assigned to an organization role. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * To use this endpoint, you must be an administrator for the organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/:role_id/teams
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndRole_id(connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string): Promise<getByOrgAndRole_id.Output>;
export declare namespace getByOrgAndRole_id {
    type Headers = IApiOrgsOrganizationRolesTeams.GetHeader;
    type Output = team_minus_role_minus_assignment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/organization-roles/:role_id/teams";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_role_minus_assignment[];
    const simulate: (connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string) => Output;
}
