import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsOrganizationRolesUsers } from "../../../../structures/IApiOrgsOrganizationRolesUsers";
import { user_minus_role_minus_assignment } from "../../../../structures/user_minus_role_minus_assignment";
/**
 * Remove all organization roles for a user.
 * Revokes all assigned organization roles from a user. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/users/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndUsername(connection: IConnection<eraseByOrgAndUsername.Headers>, org: string, username: string): Promise<void>;
export declare namespace eraseByOrgAndUsername {
    type Headers = IApiOrgsOrganizationRolesUsers.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/organization-roles/users/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndUsername.Headers>, org: string, username: string) => void;
}
/**
 * Assign an organization role to a user.
 * Assigns an organization role to a member of an organization. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/users/:username/:role_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndUsernameAndRole_id(connection: IConnection<putByOrgAndUsernameAndRole_id.Headers>, org: string, username: string, role_id: string): Promise<void>;
export declare namespace putByOrgAndUsernameAndRole_id {
    type Headers = IApiOrgsOrganizationRolesUsers.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/organization-roles/users/:username/:role_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, username: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndUsernameAndRole_id.Headers>, org: string, username: string, role_id: string) => void;
}
/**
 * Remove an organization role from a user. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/users/:username/:role_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndUsernameAndRole_id(connection: IConnection<eraseByOrgAndUsernameAndRole_id.Headers>, org: string, username: string, role_id: string): Promise<void>;
export declare namespace eraseByOrgAndUsernameAndRole_id {
    type Headers = IApiOrgsOrganizationRolesUsers.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/organization-roles/users/:username/:role_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, username: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndUsernameAndRole_id.Headers>, org: string, username: string, role_id: string) => void;
}
/**
 * List users that are assigned to an organization role.
 * Lists organization members that are assigned to an organization role. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * To use this endpoint, you must be an administrator for the organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/:role_id/users
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndRole_id(connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string): Promise<getByOrgAndRole_id.Output>;
export declare namespace getByOrgAndRole_id {
    type Headers = IApiOrgsOrganizationRolesUsers.GetHeader;
    type Output = user_minus_role_minus_assignment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/organization-roles/:role_id/users";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => user_minus_role_minus_assignment[];
    const simulate: (connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string) => Output;
}
