import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsPackages } from "../../../structures/IApiOrgsPackages";
import { packages } from "../../../structures/package";
export * as restore from "./restore";
export * as versions from "./versions";
/**
 * List packages for an organization.
 * Lists packages in an organization readable by the user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path orgs/:org/packages
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsPackages.GetHeader;
    type Query = IApiOrgsPackages.GetQuery;
    type Output = packages[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/packages";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Get a package for an organization.
 * Gets a specific package in an organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path orgs/:org/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndPackage_typeAndPackage_name(connection: IConnection<getByOrgAndPackage_typeAndPackage_name.Headers>, org: string, package_type: string, package_name: string): Promise<getByOrgAndPackage_typeAndPackage_name.Output>;
export declare namespace getByOrgAndPackage_typeAndPackage_name {
    type Headers = IApiOrgsPackages.GetHeader;
    type Output = packages;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages;
    const simulate: (connection: IConnection<getByOrgAndPackage_typeAndPackage_name.Headers>, org: string, package_type: string, package_name: string) => Output;
}
/**
 * Delete a package for an organization.
 * Deletes an entire package in an organization. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * The authenticated user must have admin permissions in the organization to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that supports granular permissions, the authenticated user must also have admin permissions to the package. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#granular-permissions-for-userorganization-scoped-packages)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` and `delete:packages` scopes to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path orgs/:org/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndPackage_typeAndPackage_name(connection: IConnection<eraseByOrgAndPackage_typeAndPackage_name.Headers>, org: string, package_type: string, package_name: string): Promise<void>;
export declare namespace eraseByOrgAndPackage_typeAndPackage_name {
    type Headers = IApiOrgsPackages.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndPackage_typeAndPackage_name.Headers>, org: string, package_type: string, package_name: string) => void;
}
