import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsPropertiesValues } from "../../../../structures/IApiOrgsPropertiesValues";
import { body } from "../../../../structures/body";
import { org_minus_repo_minus_custom_minus_property_minus_values } from "../../../../structures/org_minus_repo_minus_custom_minus_property_minus_values";
/**
 * List custom property values for organization repositories.
 * Lists organization repositories with all of their custom property values.
 * Organization members can read these properties.
 *
 * @tag orgs
 * @path orgs/:org/properties/values
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsPropertiesValues.GetHeader;
    type Query = IApiOrgsPropertiesValues.GetQuery;
    type Output = org_minus_repo_minus_custom_minus_property_minus_values[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/properties/values";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => org_minus_repo_minus_custom_minus_property_minus_values[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Create or update custom property values for organization repositories.
 * Create new or update existing custom property values for repositories in a batch that belong to an organization.
 * Each target repository will have its custom property values updated to match the values provided in the request.
 *
 * A maximum of 30 repositories can be updated in a single request.
 *
 * Using a value of `null` for a custom property will remove or 'unset' the property value from the repository.
 *
 * To use this endpoint, the authenticated user must be one of:
 * - An administrator for the organization.
 * - A user, or a user on a team, with the fine-grained permission of `custom_properties_org_values_editor` in the organization.
 *
 * @tag orgs
 * @path orgs/:org/properties/values
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrg(connection: IConnection<patchByOrg.Headers>, org: string, body: patchByOrg.Input): Promise<void>;
export declare namespace patchByOrg {
    type Headers = IApiOrgsPropertiesValues.PatchHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/properties/values";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<patchByOrg.Headers>, org: string, body: patchByOrg.Input) => void;
}
