import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsRepos } from "../../../structures/IApiOrgsRepos";
import { body } from "../../../structures/body";
import { full_minus_repository } from "../../../structures/full_minus_repository";
import { minimal_minus_repository } from "../../../structures/minimal_minus_repository";
/**
 * List organization repositories.
 * Lists repositories for the specified organization.
 *
 * > [!NOTE]
 * > In order to see the `security_and_analysis` block for a repository you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
 *
 * @tag repos
 * @path orgs/:org/repos
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsRepos.GetHeader;
    type Query = IApiOrgsRepos.GetQuery;
    type Output = minimal_minus_repository[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/repos";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => minimal_minus_repository[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Create an organization repository.
 * Creates a new repository in the specified organization. The authenticated user must be a member of the organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `public_repo` or `repo` scope to create a public repository, and `repo` scope to create a private repository.
 *
 * @tag repos
 * @path orgs/:org/repos
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsRepos.PostHeader;
    type Input = body;
    type Output = full_minus_repository;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/repos";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => full_minus_repository;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => Output;
}
