import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsSecurityManagersTeams } from "../../../../structures/IApiOrgsSecurityManagersTeams";
/**
 * Add a security manager team.
 * Adds a team as a security manager for an organization. For more information, see "[Managing security for an organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization) for an organization."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/security-managers/teams/:team_slug
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndTeam_slug(connection: IConnection<putByOrgAndTeam_slug.Headers>, org: string, team_slug: string): Promise<void>;
export declare namespace putByOrgAndTeam_slug {
    type Headers = IApiOrgsSecurityManagersTeams.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/security-managers/teams/:team_slug";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndTeam_slug.Headers>, org: string, team_slug: string) => void;
}
/**
 * Remove a security manager team.
 * Removes the security manager role from a team for an organization. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization) team from an organization."
 *
 * The authenticated user must be an administrator for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/security-managers/teams/:team_slug
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slug(connection: IConnection<eraseByOrgAndTeam_slug.Headers>, org: string, team_slug: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slug {
    type Headers = IApiOrgsSecurityManagersTeams.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/security-managers/teams/:team_slug";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slug.Headers>, org: string, team_slug: string) => void;
}
