import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsSettingsBillingActions } from "../../../../../structures/IApiOrgsSettingsBillingActions";
import { actions_minus_billing_minus_usage } from "../../../../../structures/actions_minus_billing_minus_usage";
/**
 * Get GitHub Actions billing for an organization.
 * Gets the summary of the free and paid GitHub Actions minutes used.
 *
 * Paid minutes only apply to workflows in private repositories that use GitHub-hosted runners. Minutes used is listed for each GitHub-hosted runner operating system. Any job re-runs are also included in the usage. The usage returned includes any minute multipliers for macOS and Windows runners, and is rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` or `admin:org` scope to use this endpoint.
 *
 * @tag billing
 * @path orgs/:org/settings/billing/actions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsSettingsBillingActions.GetHeader;
    type Output = actions_minus_billing_minus_usage;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/settings/billing/actions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_billing_minus_usage;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
