import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsTeamsDiscussionsCommentsReactions } from "../../../../../../structures/IApiOrgsTeamsDiscussionsCommentsReactions";
import { body } from "../../../../../../structures/body";
import { reaction } from "../../../../../../structures/reaction";
/**
 * List reactions for a team discussion comment.
 * List the reactions to a [team discussion comment](https://docs.github.com/rest/teams/discussion-comments#get-a-discussion-comment).
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag reactions
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndDiscussion_numberAndComment_number(connection: IConnection<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, query: getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Query): Promise<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Output>;
export declare namespace getByOrgAndTeam_slugAndDiscussion_numberAndComment_number {
    type Headers = IApiOrgsTeamsDiscussionsCommentsReactions.GetHeader;
    type Query = IApiOrgsTeamsDiscussionsCommentsReactions.GetQuery;
    type Output = reaction[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string, query: getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction[];
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, query: getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Query) => Output;
}
/**
 * Create reaction for a team discussion comment.
 * Create a reaction to a [team discussion comment](https://docs.github.com/rest/teams/discussion-comments#get-a-discussion-comment).
 *
 * A response with an HTTP `200` status means that you already added the reaction type to this team discussion comment.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag reactions
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndTeam_slugAndDiscussion_numberAndComment_number(connection: IConnection<postByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, body: postByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Input): Promise<postByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Output>;
export declare namespace postByOrgAndTeam_slugAndDiscussion_numberAndComment_number {
    type Headers = IApiOrgsTeamsDiscussionsCommentsReactions.PostHeader;
    type Input = body;
    type Output = reaction;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction;
    const simulate: (connection: IConnection<postByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, body: postByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Input) => Output;
}
/**
 * Delete team discussion comment reaction.
 * > [!NOTE]
 * > You can also specify a team or organization with `team_id` and `org_id` using the route `DELETE /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions/:reaction_id`.
 *
 * Delete a reaction to a [team discussion comment](https://docs.github.com/rest/teams/discussion-comments#get-a-discussion-comment).
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag reactions
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions/:reaction_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_numberAndReaction_id(connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_numberAndReaction_id.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, reaction_id: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_numberAndReaction_id {
    type Headers = IApiOrgsTeamsDiscussionsCommentsReactions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number/reactions/:reaction_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string, reaction_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_numberAndReaction_id.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, reaction_id: string) => void;
}
