import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsTeamsMemberships } from "../../../../structures/IApiOrgsTeamsMemberships";
import { body } from "../../../../structures/body";
import { team_minus_membership } from "../../../../structures/team_minus_membership";
/**
 * Get team membership for a user.
 * Team members will include the members of child teams.
 *
 * To get a user's membership with a team, the team must be visible to the authenticated user.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/memberships/{username}`.
 *
 * > [!NOTE]
 * > The response contains the `state` of the membership and the member's `role`.
 *
 * The `role` for organization owners is set to `maintainer`. For more information about `maintainer` roles, see [Create a team](https://docs.github.com/rest/teams/teams#create-a-team).
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndUsername(connection: IConnection<getByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string): Promise<getByOrgAndTeam_slugAndUsername.Output>;
export declare namespace getByOrgAndTeam_slugAndUsername {
    type Headers = IApiOrgsTeamsMemberships.GetHeader;
    type Output = team_minus_membership;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/memberships/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_membership;
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string) => Output;
}
/**
 * Add or update team membership for a user.
 * Adds an organization member to a team. An authenticated organization owner or team maintainer can add organization members to a team.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * > [!NOTE]
 * > When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * An organization owner can add someone who is not part of the team's organization to a team. When an organization owner adds someone to a team who is not an organization member, this endpoint will send an invitation to the person via email. This newly-created membership will be in the "pending" state until the person accepts the invitation, at which point the membership will transition to the "active" state and the user will be added as a member of the team.
 *
 * If the user is already a member of the team, this endpoint will update the role of the team member's role. To update the membership of a team member, the authenticated user must be an organization owner or a team maintainer.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `PUT /organizations/{org_id}/team/{team_id}/memberships/{username}`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndTeam_slugAndUsername(connection: IConnection<putByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string, body: putByOrgAndTeam_slugAndUsername.Input): Promise<putByOrgAndTeam_slugAndUsername.Output>;
export declare namespace putByOrgAndTeam_slugAndUsername {
    type Headers = IApiOrgsTeamsMemberships.PutHeader;
    type Input = body;
    type Output = team_minus_membership;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/teams/:team_slug/memberships/:username";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_membership;
    const simulate: (connection: IConnection<putByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string, body: putByOrgAndTeam_slugAndUsername.Input) => Output;
}
/**
 * Remove team membership for a user.
 * To remove a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with. Removing team membership does not delete the user, it just removes their membership from the team.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * > [!NOTE]
 * > When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/memberships/{username}`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndUsername(connection: IConnection<eraseByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndUsername {
    type Headers = IApiOrgsTeamsMemberships.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/teams/:team_slug/memberships/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndUsername.Headers>, org: string, team_slug: string, username: string) => void;
}
