import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsTeamsProjects } from "../../../../structures/IApiOrgsTeamsProjects";
import { body } from "../../../../structures/body";
import { team_minus_project } from "../../../../structures/team_minus_project";
/**
 * List team projects.
 * Lists the organization projects for a team.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/projects`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/projects
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slug(connection: IConnection<getByOrgAndTeam_slug.Headers>, org: string, team_slug: string): Promise<getByOrgAndTeam_slug.Output>;
export declare namespace getByOrgAndTeam_slug {
    type Headers = IApiOrgsTeamsProjects.GetHeader;
    type Output = team_minus_project[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/projects";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_project[];
    const simulate: (connection: IConnection<getByOrgAndTeam_slug.Headers>, org: string, team_slug: string) => Output;
}
/**
 * Check team permissions for a project.
 * Checks whether a team has `read`, `write`, or `admin` permissions for an organization project. The response includes projects inherited from a parent team.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndProject_id(connection: IConnection<getByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string): Promise<getByOrgAndTeam_slugAndProject_id.Output>;
export declare namespace getByOrgAndTeam_slugAndProject_id {
    type Headers = IApiOrgsTeamsProjects.GetHeader;
    type Output = team_minus_project;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/projects/:project_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_project;
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string) => Output;
}
/**
 * Add or update team project permissions.
 * Adds an organization project to a team. To add a project to a team or update the team's permission on a project, the authenticated user must have `admin` permissions for the project. The project and team must be part of the same organization.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `PUT /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndTeam_slugAndProject_id(connection: IConnection<putByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string, body: putByOrgAndTeam_slugAndProject_id.Input): Promise<void>;
export declare namespace putByOrgAndTeam_slugAndProject_id {
    type Headers = IApiOrgsTeamsProjects.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/teams/:team_slug/projects/:project_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string, body: putByOrgAndTeam_slugAndProject_id.Input) => void;
}
/**
 * Remove a project from a team.
 * Removes an organization project from a team. An organization owner or a team maintainer can remove any project from the team. To remove a project from a team as an organization member, the authenticated user must have `read` access to both the team and project, or `admin` access to the team or project. This endpoint removes the project from the team, but does not delete the project.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndProject_id(connection: IConnection<eraseByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndProject_id {
    type Headers = IApiOrgsTeamsProjects.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/teams/:team_slug/projects/:project_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndProject_id.Headers>, org: string, team_slug: string, project_id: string) => void;
}
