import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiProjects } from "../../structures/IApiProjects";
import { body } from "../../structures/body";
import { project } from "../../structures/project";
export * as columns from "./columns";
export * as collaborators from "./collaborators";
/**
 * Get a project.
 * Gets a project by its `id`. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
 *
 * @tag projects
 * @path projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByProject_id(connection: IConnection<getByProject_id.Headers>, project_id: string): Promise<getByProject_id.Output>;
export declare namespace getByProject_id {
    type Headers = IApiProjects.GetHeader;
    type Output = project;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/projects/:project_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => project;
    const simulate: (connection: IConnection<getByProject_id.Headers>, project_id: string) => Output;
}
/**
 * Update a project.
 * Updates a project board's information. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
 *
 * @tag projects
 * @path projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByProject_id(connection: IConnection<patchByProject_id.Headers>, project_id: string, body: patchByProject_id.Input): Promise<patchByProject_id.Output>;
export declare namespace patchByProject_id {
    type Headers = IApiProjects.PatchHeader;
    type Input = body;
    type Output = project;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/projects/:project_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => project;
    const simulate: (connection: IConnection<patchByProject_id.Headers>, project_id: string, body: patchByProject_id.Input) => Output;
}
/**
 * Delete a project.
 * Deletes a project board. Returns a `404 Not Found` status if projects are disabled.
 *
 * @tag projects
 * @path projects/:project_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByProject_id(connection: IConnection<eraseByProject_id.Headers>, project_id: string): Promise<void>;
export declare namespace eraseByProject_id {
    type Headers = IApiProjects.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/projects/:project_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (project_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByProject_id.Headers>, project_id: string) => void;
}
