import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiReposImportAuthors } from "../../../../structures/IApiReposImportAuthors";
import { body } from "../../../../structures/body";
import { porter_minus_author } from "../../../../structures/porter_minus_author";
/**
 * Get commit authors.
 * Each type of source control system represents authors in a different way. For example, a Git commit author has a display name and an email address, but a Subversion commit author just has a username. The GitHub Importer will make the author information valid, but the author might not be correct. For example, it will change the bare Subversion username `hubot` into something like `hubot <hubot@12341234-abab-fefe-8787-fedcba987654>`.
 *
 * This endpoint and the [Map a commit author](https://docs.github.com/rest/migrations/source-imports#map-a-commit-author) endpoint allow you to provide correct Git author information.
 *
 * > [!WARNING]
 * > **Deprecation notice:** Due to very low levels of usage and available alternatives, this endpoint is deprecated and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the [changelog](https://gh.io/source-imports-api-deprecation).
 *
 * @tag migrations
 * @deprecated
 * @path repos/:owner/:repo/import/authors
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposImportAuthors.GetHeader;
    type Output = porter_minus_author[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/import/authors";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => porter_minus_author[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Map a commit author.
 * Update an author's identity for the import. Your application can continue updating authors any time before you push
 * new commits to the repository.
 *
 * > [!WARNING]
 * > **Deprecation notice:** Due to very low levels of usage and available alternatives, this endpoint is deprecated and will no longer be available from 00:00 UTC on April 12, 2024. For more details and alternatives, see the [changelog](https://gh.io/source-imports-api-deprecation).
 *
 * @tag migrations
 * @deprecated
 * @path repos/:owner/:repo/import/authors/:author_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndAuthor_id(connection: IConnection<patchByOwnerAndRepoAndAuthor_id.Headers>, owner: string, repo: string, author_id: number & tags.Type<"int32">, body: patchByOwnerAndRepoAndAuthor_id.Input): Promise<patchByOwnerAndRepoAndAuthor_id.Output>;
export declare namespace patchByOwnerAndRepoAndAuthor_id {
    type Headers = IApiReposImportAuthors.PatchHeader;
    type Input = body;
    type Output = porter_minus_author;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/import/authors/:author_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, author_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => porter_minus_author;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndAuthor_id.Headers>, owner: string, repo: string, author_id: number & tags.Type<"int32">, body: patchByOwnerAndRepoAndAuthor_id.Input) => Output;
}
