import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsCaches } from "../../../../structures/IApiReposActionsCaches";
import { actions_minus_cache_minus_list } from "../../../../structures/actions_minus_cache_minus_list";
/**
 * List GitHub Actions caches for a repository.
 * Lists the GitHub Actions caches for a repository.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/caches
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsCaches.GetHeader;
    type Output = actions_minus_cache_minus_list;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/caches";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_cache_minus_list;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Delete GitHub Actions caches for a repository (using a cache key).
 * Deletes one or more GitHub Actions caches for a repository, using a complete cache key. By default, all caches that match the provided key are deleted, but you can optionally provide a Git ref to restrict deletions to caches that match both the provided key and the Git ref.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/caches
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepo(connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<eraseByOwnerAndRepo.Output>;
export declare namespace eraseByOwnerAndRepo {
    type Headers = IApiReposActionsCaches.DeleteHeader;
    type Output = actions_minus_cache_minus_list;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/caches";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_cache_minus_list;
    const simulate: (connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Delete a GitHub Actions cache for a repository (using a cache ID).
 * Deletes a GitHub Actions cache for a repository, using a cache ID.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/caches/:cache_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndCache_id(connection: IConnection<eraseByOwnerAndRepoAndCache_id.Headers>, owner: string, repo: string, cache_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndCache_id {
    type Headers = IApiReposActionsCaches.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/caches/:cache_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, cache_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndCache_id.Headers>, owner: string, repo: string, cache_id: string) => void;
}
