import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsPermissionsWorkflow } from "../../../../../structures/IApiReposActionsPermissionsWorkflow";
import { actions_minus_get_minus_default_minus_workflow_minus_permissions } from "../../../../../structures/actions_minus_get_minus_default_minus_workflow_minus_permissions";
import { actions_minus_set_minus_default_minus_workflow_minus_permissions } from "../../../../../structures/actions_minus_set_minus_default_minus_workflow_minus_permissions";
/**
 * Get default workflow permissions for a repository.
 * Gets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in a repository,
 * as well as if GitHub Actions can submit approving pull request reviews.
 * For more information, see "[Setting the permissions of the GITHUB_TOKEN for your repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#setting-the-permissions-of-the-github_token-for-your-repository)."
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/permissions/workflow
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsPermissionsWorkflow.GetHeader;
    type Output = actions_minus_get_minus_default_minus_workflow_minus_permissions;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/permissions/workflow";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_get_minus_default_minus_workflow_minus_permissions;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Set default workflow permissions for a repository.
 * Sets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in a repository, and sets if GitHub Actions
 * can submit approving pull request reviews.
 * For more information, see "[Setting the permissions of the GITHUB_TOKEN for your repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#setting-the-permissions-of-the-github_token-for-your-repository)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/permissions/workflow
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposActionsPermissionsWorkflow.PutHeader;
    type Input = actions_minus_set_minus_default_minus_workflow_minus_permissions;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/actions/permissions/workflow";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input) => void;
}
