import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunnersRemoveToken } from "../../../../../structures/IApiReposActionsRunnersRemoveToken";
import { authentication_minus_token } from "../../../../../structures/authentication_minus_token";
/**
 * Create a remove token for a repository.
 * Returns a token that you can pass to the `config` script to remove a self-hosted runner from an repository. The token expires after one hour.
 *
 * For example, you can replace `TOKEN` in the following example with the registration token provided by this endpoint to remove your self-hosted runner from an organization:
 *
 * ```
 * ./config.sh remove --token TOKEN
 * ```
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/remove-token
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposActionsRunnersRemoveToken.PostHeader;
    type Output = authentication_minus_token;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/actions/runners/remove-token";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => authentication_minus_token;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
