import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRuns } from "../../../../structures/IApiReposActionsRuns";
import { response } from "../../../../structures/response";
import { workflow_minus_run } from "../../../../structures/workflow_minus_run";
export * as approvals from "./approvals";
export * as approve from "./approve";
export * as artifacts from "./artifacts";
export * as attempts from "./attempts";
export * as cancel from "./cancel";
export * as deployment_protection_rule from "./deployment_protection_rule";
export * as force_cancel from "./force_cancel";
export * as jobs from "./jobs";
export * as logs from "./logs";
export * as pending_deployments from "./pending_deployments";
export * as rerun from "./rerun";
export * as rerun_failed_jobs from "./rerun_failed_jobs";
export * as timing from "./timing";
/**
 * List workflow runs for a repository.
 * Lists all workflow runs for a repository. You can use parameters to narrow the list of results. For more information about using parameters, see [Parameters](https://docs.github.com/rest/guides/getting-started-with-the-rest-api#parameters).
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * This API will return up to 1,000 results for each search when using the following parameters: `actor`, `branch`, `check_suite_id`, `created`, `event`, `head_sha`, `status`.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsRuns.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runs";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a workflow run.
 * Gets a specific workflow run.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRun_id(connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<getByOwnerAndRepoAndRun_id.Output>;
export declare namespace getByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRuns.GetHeader;
    type Output = workflow_minus_run;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => workflow_minus_run;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => Output;
}
/**
 * Delete a workflow run.
 * Deletes a specific workflow run.
 *
 * Anyone with write access to the repository can use this endpoint.
 *
 * If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRun_id(connection: IConnection<eraseByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRuns.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => void;
}
