import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunsLogs } from "../../../../../structures/IApiReposActionsRunsLogs";
/**
 * Download workflow run logs.
 * Gets a redirect URL to download an archive of log files for a workflow run. This link expires after 1 minute. Look for
 * `Location:` in the response header to find the URL for the download.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id/logs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRun_id(connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<void>;
export declare namespace getByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRunsLogs.GetHeader;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id/logs";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => void;
}
/**
 * Delete workflow run logs.
 * Deletes all logs for a workflow run.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id/logs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRun_id(connection: IConnection<eraseByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRunsLogs.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id/logs";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => void;
}
