import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsVariables } from "../../../../structures/IApiReposActionsVariables";
import { actions_minus_variable } from "../../../../structures/actions_minus_variable";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { response } from "../../../../structures/response";
/**
 * List repository variables.
 * Lists all repository variables.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsVariables.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/variables";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create a repository variable.
 * Creates a repository variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposActionsVariables.PostHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/actions/variables";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a repository variable.
 * Gets a specific variable in a repository.
 *
 * The authenticated user must have collaborator access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndName(connection: IConnection<getByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string): Promise<getByOwnerAndRepoAndName.Output>;
export declare namespace getByOwnerAndRepoAndName {
    type Headers = IApiReposActionsVariables.GetHeader;
    type Output = actions_minus_variable;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_variable;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string) => Output;
}
/**
 * Update a repository variable.
 * Updates a repository variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndName(connection: IConnection<patchByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string, body: patchByOwnerAndRepoAndName.Input): Promise<void>;
export declare namespace patchByOwnerAndRepoAndName {
    type Headers = IApiReposActionsVariables.PatchHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/actions/variables/:name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string, body: patchByOwnerAndRepoAndName.Input) => void;
}
/**
 * Delete a repository variable.
 * Deletes a repository variable using the variable name.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndName(connection: IConnection<eraseByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndName {
    type Headers = IApiReposActionsVariables.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string) => void;
}
