import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsWorkflowsTiming } from "../../../../../structures/IApiReposActionsWorkflowsTiming";
import { workflow_minus_usage } from "../../../../../structures/workflow_minus_usage";
/**
 * Get workflow usage.
 * Gets the number of billable minutes used by a specific workflow during the current billing cycle. Billable minutes only apply to workflows in private repositories that use GitHub-hosted runners. Usage is listed for each GitHub-hosted runner operating system in milliseconds. Any job re-runs are also included in the usage. The usage does not include the multiplier for macOS and Windows runners and is not rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/workflows/:workflow_id/timing
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndWorkflow_id(connection: IConnection<getByOwnerAndRepoAndWorkflow_id.Headers>, owner: string, repo: string, workflow_id: string): Promise<getByOwnerAndRepoAndWorkflow_id.Output>;
export declare namespace getByOwnerAndRepoAndWorkflow_id {
    type Headers = IApiReposActionsWorkflowsTiming.GetHeader;
    type Output = workflow_minus_usage;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/workflows/:workflow_id/timing";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, workflow_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => workflow_minus_usage;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndWorkflow_id.Headers>, owner: string, repo: string, workflow_id: string) => Output;
}
