import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposAutolinks } from "../../../structures/IApiReposAutolinks";
import { autolink } from "../../../structures/autolink";
import { body } from "../../../structures/body";
/**
 * Get all autolinks of a repository.
 * Gets all autolinks that are configured for a repository.
 *
 * Information about autolinks are only available to repository administrators.
 *
 * @tag repos
 * @path repos/:owner/:repo/autolinks
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposAutolinks.GetHeader;
    type Output = autolink[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/autolinks";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => autolink[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create an autolink reference for a repository.
 * Users with admin access to the repository can create an autolink.
 *
 * @tag repos
 * @path repos/:owner/:repo/autolinks
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposAutolinks.PostHeader;
    type Input = body;
    type Output = autolink;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/autolinks";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => autolink;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get an autolink reference of a repository.
 * This returns a single autolink reference by ID that was configured for the given repository.
 *
 * Information about autolinks are only available to repository administrators.
 *
 * @tag repos
 * @path repos/:owner/:repo/autolinks/:autolink_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndAutolink_id(connection: IConnection<getByOwnerAndRepoAndAutolink_id.Headers>, owner: string, repo: string, autolink_id: string): Promise<getByOwnerAndRepoAndAutolink_id.Output>;
export declare namespace getByOwnerAndRepoAndAutolink_id {
    type Headers = IApiReposAutolinks.GetHeader;
    type Output = autolink;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/autolinks/:autolink_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, autolink_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => autolink;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndAutolink_id.Headers>, owner: string, repo: string, autolink_id: string) => Output;
}
/**
 * Delete an autolink reference from a repository.
 * This deletes a single autolink reference by ID that was configured for the given repository.
 *
 * Information about autolinks are only available to repository administrators.
 *
 * @tag repos
 * @path repos/:owner/:repo/autolinks/:autolink_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndAutolink_id(connection: IConnection<eraseByOwnerAndRepoAndAutolink_id.Headers>, owner: string, repo: string, autolink_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndAutolink_id {
    type Headers = IApiReposAutolinks.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/autolinks/:autolink_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, autolink_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndAutolink_id.Headers>, owner: string, repo: string, autolink_id: string) => void;
}
