import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposBranchesProtectionRequiredPullRequestReviews } from "../../../../../structures/IApiReposBranchesProtectionRequiredPullRequestReviews";
import { body } from "../../../../../structures/body";
import { protected_minus_branch_minus_pull_minus_request_minus_review } from "../../../../../structures/protected_minus_branch_minus_pull_minus_request_minus_review";
/**
 * Get pull request review protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndBranch(connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<getByOwnerAndRepoAndBranch.Output>;
export declare namespace getByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredPullRequestReviews.GetHeader;
    type Output = protected_minus_branch_minus_pull_minus_request_minus_review;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => protected_minus_branch_minus_pull_minus_request_minus_review;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => Output;
}
/**
 * Update pull request review protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Updating pull request review enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
 *
 * > [!NOTE]
 * > Passing new arrays of `users` and `teams` replaces their previous values.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndBranch(connection: IConnection<patchByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: patchByOwnerAndRepoAndBranch.Input): Promise<patchByOwnerAndRepoAndBranch.Output>;
export declare namespace patchByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredPullRequestReviews.PatchHeader;
    type Input = body;
    type Output = protected_minus_branch_minus_pull_minus_request_minus_review;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => protected_minus_branch_minus_pull_minus_request_minus_review;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: patchByOwnerAndRepoAndBranch.Input) => Output;
}
/**
 * Delete pull request review protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndBranch(connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredPullRequestReviews.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_pull_request_reviews";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => void;
}
