import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposBranchesProtectionRequiredSignatures } from "../../../../../structures/IApiReposBranchesProtectionRequiredSignatures";
import { protected_minus_branch_minus_admin_minus_enforced } from "../../../../../structures/protected_minus_branch_minus_admin_minus_enforced";
/**
 * Get commit signature protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to check whether a branch requires signed commits. An enabled status of `true` indicates you must sign commits on this branch. For more information, see [Signing commits with GPG](https://docs.github.com/articles/signing-commits-with-gpg) in GitHub Help.
 *
 * > [!NOTE]
 * > You must enable branch protection to require signed commits.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_signatures
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndBranch(connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<getByOwnerAndRepoAndBranch.Output>;
export declare namespace getByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredSignatures.GetHeader;
    type Output = protected_minus_branch_minus_admin_minus_enforced;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_signatures";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => protected_minus_branch_minus_admin_minus_enforced;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => Output;
}
/**
 * Create commit signature protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to require signed commits on a branch. You must enable branch protection to require signed commits.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_signatures
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndBranch(connection: IConnection<postByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<postByOwnerAndRepoAndBranch.Output>;
export declare namespace postByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredSignatures.PostHeader;
    type Output = protected_minus_branch_minus_admin_minus_enforced;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_signatures";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => protected_minus_branch_minus_admin_minus_enforced;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => Output;
}
/**
 * Delete commit signature protection.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to disable required signed commits on a branch. You must enable branch protection to require signed commits.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/required_signatures
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndBranch(connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRequiredSignatures.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/required_signatures";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => void;
}
