import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCheckRuns } from "../../../structures/IApiReposCheckRuns";
import { check_minus_run } from "../../../structures/check_minus_run";
export * as annotations from "./annotations";
export * as rerequest from "./rerequest";
/**
 * Create a check run.
 * Creates a new check run for a specific commit in a repository.
 *
 * To create a check run, you must use a GitHub App. OAuth apps and authenticated users are not able to create a check suite.
 *
 * In a check suite, GitHub limits the number of check runs with the same name to 1000. Once these check runs exceed 1000, GitHub will start to automatically delete older check runs.
 *
 * > [!NOTE]
 * > The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * @tag checks
 * @path repos/:owner/:repo/check-runs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposCheckRuns.PostHeader;
    type Input = any | any;
    type Output = check_minus_run;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/check-runs";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_run;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a check run.
 * Gets a single check run using its `id`.
 *
 * > [!NOTE]
 * > The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint on a private repository.
 *
 * @tag checks
 * @path repos/:owner/:repo/check-runs/:check_run_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndCheck_run_id(connection: IConnection<getByOwnerAndRepoAndCheck_run_id.Headers>, owner: string, repo: string, check_run_id: string): Promise<getByOwnerAndRepoAndCheck_run_id.Output>;
export declare namespace getByOwnerAndRepoAndCheck_run_id {
    type Headers = IApiReposCheckRuns.GetHeader;
    type Output = check_minus_run;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/check-runs/:check_run_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, check_run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_run;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndCheck_run_id.Headers>, owner: string, repo: string, check_run_id: string) => Output;
}
/**
 * Update a check run.
 * Updates a check run for a specific commit in a repository.
 *
 * > [!NOTE]
 * > The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * OAuth apps and personal access tokens (classic) cannot use this endpoint.
 *
 * @tag checks
 * @path repos/:owner/:repo/check-runs/:check_run_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndCheck_run_id(connection: IConnection<patchByOwnerAndRepoAndCheck_run_id.Headers>, owner: string, repo: string, check_run_id: string, body: patchByOwnerAndRepoAndCheck_run_id.Input): Promise<patchByOwnerAndRepoAndCheck_run_id.Output>;
export declare namespace patchByOwnerAndRepoAndCheck_run_id {
    type Headers = IApiReposCheckRuns.PatchHeader;
    type Input = any | any;
    type Output = check_minus_run;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/check-runs/:check_run_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, check_run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_run;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndCheck_run_id.Headers>, owner: string, repo: string, check_run_id: string, body: patchByOwnerAndRepoAndCheck_run_id.Input) => Output;
}
