import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCodeScanningAlerts } from "../../../../structures/IApiReposCodeScanningAlerts";
import { body } from "../../../../structures/body";
import { code_minus_scanning_minus_alert } from "../../../../structures/code_minus_scanning_minus_alert";
import { code_minus_scanning_minus_alert_minus_items } from "../../../../structures/code_minus_scanning_minus_alert_minus_items";
export * as instances from "./instances";
/**
 * List code scanning alerts for a repository.
 * Lists code scanning alerts.
 *
 * The response includes a `most_recent_instance` object.
 * This provides details of the most recent instance of this alert
 * for the default branch (or for the specified Git reference if you used `ref` in the request).
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposCodeScanningAlerts.GetHeader;
    type Query = IApiReposCodeScanningAlerts.GetQuery;
    type Output = code_minus_scanning_minus_alert_minus_items[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/code-scanning/alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, query: getByOwnerAndRepo.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_alert_minus_items[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query) => Output;
}
/**
 * Get a code scanning alert.
 * Gets a single code scanning alert.
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndAlert_number(connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string): Promise<getByOwnerAndRepoAndAlert_number.Output>;
export declare namespace getByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposCodeScanningAlerts.GetHeader;
    type Output = code_minus_scanning_minus_alert;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/code-scanning/alerts/:alert_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_alert;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string) => Output;
}
/**
 * Update a code scanning alert.
 * Updates the status of a single code scanning alert.
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndAlert_number(connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input): Promise<patchByOwnerAndRepoAndAlert_number.Output>;
export declare namespace patchByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposCodeScanningAlerts.PatchHeader;
    type Input = body;
    type Output = code_minus_scanning_minus_alert;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/code-scanning/alerts/:alert_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_alert;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input) => Output;
}
