import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCodeScanningCodeqlDatabases } from "../../../../../structures/IApiReposCodeScanningCodeqlDatabases";
import { code_minus_scanning_minus_codeql_minus_database } from "../../../../../structures/code_minus_scanning_minus_codeql_minus_database";
/**
 * List CodeQL databases for a repository.
 * Lists the CodeQL databases that are available in a repository.
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/codeql/databases
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposCodeScanningCodeqlDatabases.GetHeader;
    type Output = code_minus_scanning_minus_codeql_minus_database[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/code-scanning/codeql/databases";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_codeql_minus_database[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a CodeQL database for a repository.
 * Gets a CodeQL database for a language in a repository.
 *
 * By default this endpoint returns JSON metadata about the CodeQL database. To
 * download the CodeQL database binary content, set the `Accept` header of the request
 * to [`application/zip`](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types), and make sure
 * your HTTP client is configured to follow redirects or use the `Location` header
 * to make a second request to get the redirect URL.
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @param language The language of the CodeQL database.
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/codeql/databases/:language
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndLanguage(connection: IConnection<getByOwnerAndRepoAndLanguage.Headers>, owner: string, repo: string, language: string): Promise<getByOwnerAndRepoAndLanguage.Output>;
export declare namespace getByOwnerAndRepoAndLanguage {
    type Headers = IApiReposCodeScanningCodeqlDatabases.GetHeader;
    type Output = code_minus_scanning_minus_codeql_minus_database;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/code-scanning/codeql/databases/:language";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, language: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_codeql_minus_database;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndLanguage.Headers>, owner: string, repo: string, language: string) => Output;
}
