import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCodespaces } from "../../../structures/IApiReposCodespaces";
import { body } from "../../../structures/body";
import { codespace } from "../../../structures/codespace";
import { response } from "../../../structures/response";
export * as devcontainers from "./devcontainers";
export * as machines from "./machines";
export * as _new from "./_new";
export * as permissions_check from "./permissions_check";
export * as secrets from "./secrets";
/**
 * List codespaces in a repository for the authenticated user.
 * Lists the codespaces associated to a specified repository and the authenticated user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposCodespaces.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/codespaces";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create a codespace in a repository.
 * Creates a codespace owned by the authenticated user in the specified repository.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposCodespaces.PostHeader;
    type Input = body;
    type Output = codespace;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/codespaces";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespace;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
