import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCommitsCheckRuns } from "../../../../structures/IApiReposCommitsCheckRuns";
import { response } from "../../../../structures/response";
/**
 * List check runs for a Git reference.
 * Lists check runs for a commit ref. The `ref` can be a SHA, branch name, or a tag name.
 *
 * > [!NOTE]
 * > The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * If there are more than 1000 check suites on a single git reference, this endpoint will limit check runs to the 1000 most recent check suites. To iterate over all possible check runs, use the [List check suites for a Git reference](https://docs.github.com/rest/reference/checks#list-check-suites-for-a-git-reference) endpoint and provide the `check_suite_id` parameter to the [List check runs in a check suite](https://docs.github.com/rest/reference/checks#list-check-runs-in-a-check-suite) endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint on a private repository.
 *
 * @tag checks
 * @path repos/:owner/:repo/commits/:ref/check-runs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRef(connection: IConnection<getByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string, query: getByOwnerAndRepoAndRef.Query): Promise<getByOwnerAndRepoAndRef.Output>;
export declare namespace getByOwnerAndRepoAndRef {
    type Headers = IApiReposCommitsCheckRuns.GetHeader;
    type Query = IApiReposCommitsCheckRuns.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/commits/:ref/check-runs";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, ref: string, query: getByOwnerAndRepoAndRef.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string, query: getByOwnerAndRepoAndRef.Query) => Output;
}
