import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiReposDeploymentsStatuses } from "../../../../structures/IApiReposDeploymentsStatuses";
import { body } from "../../../../structures/body";
import { deployment_minus_status } from "../../../../structures/deployment_minus_status";
/**
 * List deployment statuses.
 * Users with pull access can view deployment statuses for a deployment:
 *
 * @tag repos
 * @path repos/:owner/:repo/deployments/:deployment_id/statuses
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndDeployment_id(connection: IConnection<getByOwnerAndRepoAndDeployment_id.Headers>, owner: string, repo: string, deployment_id: string): Promise<getByOwnerAndRepoAndDeployment_id.Output>;
export declare namespace getByOwnerAndRepoAndDeployment_id {
    type Headers = IApiReposDeploymentsStatuses.GetHeader;
    type Output = deployment_minus_status[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/deployments/:deployment_id/statuses";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, deployment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => deployment_minus_status[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndDeployment_id.Headers>, owner: string, repo: string, deployment_id: string) => Output;
}
/**
 * Create a deployment status.
 * Users with `push` access can create deployment statuses for a given deployment.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo_deployment` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/deployments/:deployment_id/statuses
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndDeployment_id(connection: IConnection<postByOwnerAndRepoAndDeployment_id.Headers>, owner: string, repo: string, deployment_id: string, body: postByOwnerAndRepoAndDeployment_id.Input): Promise<postByOwnerAndRepoAndDeployment_id.Output>;
export declare namespace postByOwnerAndRepoAndDeployment_id {
    type Headers = IApiReposDeploymentsStatuses.PostHeader;
    type Input = body;
    type Output = deployment_minus_status;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/deployments/:deployment_id/statuses";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, deployment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => deployment_minus_status;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndDeployment_id.Headers>, owner: string, repo: string, deployment_id: string, body: postByOwnerAndRepoAndDeployment_id.Input) => Output;
}
/**
 * Get a deployment status.
 * Users with pull access can view a deployment status for a deployment:
 *
 * @tag repos
 * @path repos/:owner/:repo/deployments/:deployment_id/statuses/:status_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndDeployment_idAndStatus_id(connection: IConnection<getByOwnerAndRepoAndDeployment_idAndStatus_id.Headers>, owner: string, repo: string, deployment_id: string, status_id: number & tags.Type<"int32">): Promise<getByOwnerAndRepoAndDeployment_idAndStatus_id.Output>;
export declare namespace getByOwnerAndRepoAndDeployment_idAndStatus_id {
    type Headers = IApiReposDeploymentsStatuses.GetHeader;
    type Output = deployment_minus_status;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/deployments/:deployment_id/statuses/:status_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, deployment_id: string, status_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => deployment_minus_status;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndDeployment_idAndStatus_id.Headers>, owner: string, repo: string, deployment_id: string, status_id: number & tags.Type<"int32">) => Output;
}
