import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposEnvironmentsVariables } from "../../../../structures/IApiReposEnvironmentsVariables";
import { actions_minus_variable } from "../../../../structures/actions_minus_variable";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { response } from "../../../../structures/response";
/**
 * List environment variables.
 * Lists all environment variables.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndEnvironment_name(connection: IConnection<getByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string): Promise<getByOwnerAndRepoAndEnvironment_name.Output>;
export declare namespace getByOwnerAndRepoAndEnvironment_name {
    type Headers = IApiReposEnvironmentsVariables.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/variables";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string) => Output;
}
/**
 * Create an environment variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/variables
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndEnvironment_name(connection: IConnection<postByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string, body: postByOwnerAndRepoAndEnvironment_name.Input): Promise<postByOwnerAndRepoAndEnvironment_name.Output>;
export declare namespace postByOwnerAndRepoAndEnvironment_name {
    type Headers = IApiReposEnvironmentsVariables.PostHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/variables";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string, body: postByOwnerAndRepoAndEnvironment_name.Input) => Output;
}
/**
 * Get an environment variable.
 * Gets a specific variable in an environment.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndEnvironment_nameAndName(connection: IConnection<getByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string): Promise<getByOwnerAndRepoAndEnvironment_nameAndName.Output>;
export declare namespace getByOwnerAndRepoAndEnvironment_nameAndName {
    type Headers = IApiReposEnvironmentsVariables.GetHeader;
    type Output = actions_minus_variable;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_variable;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string) => Output;
}
/**
 * Update an environment variable.
 * Updates an environment variable that you can reference in a GitHub Actions workflow.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndEnvironment_nameAndName(connection: IConnection<patchByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string, body: patchByOwnerAndRepoAndEnvironment_nameAndName.Input): Promise<void>;
export declare namespace patchByOwnerAndRepoAndEnvironment_nameAndName {
    type Headers = IApiReposEnvironmentsVariables.PatchHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/variables/:name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string, body: patchByOwnerAndRepoAndEnvironment_nameAndName.Input) => void;
}
/**
 * Delete an environment variable.
 * Deletes an environment variable using the variable name.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/variables/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndEnvironment_nameAndName(connection: IConnection<eraseByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndEnvironment_nameAndName {
    type Headers = IApiReposEnvironmentsVariables.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/variables/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndEnvironment_nameAndName.Headers>, owner: string, repo: string, environment_name: string, name: string) => void;
}
