import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposGitRefs } from "../../../../structures/IApiReposGitRefs";
import { body } from "../../../../structures/body";
import { git_minus_ref } from "../../../../structures/git_minus_ref";
/**
 * Create a reference.
 * Creates a reference for your repository. You are unable to create new references for empty repositories, even if the commit SHA-1 hash used exists. Empty repositories are repositories without branches.
 *
 * @tag git
 * @path repos/:owner/:repo/git/refs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposGitRefs.PostHeader;
    type Input = body;
    type Output = git_minus_ref;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/git/refs";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => git_minus_ref;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Update a reference.
 * Updates the provided reference to point to a new SHA. For more information, see "[Git References](https://git-scm.com/book/en/v2/Git-Internals-Git-References)" in the Git documentation.
 *
 * @tag git
 * @path repos/:owner/:repo/git/refs/:ref
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndRef(connection: IConnection<patchByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string, body: patchByOwnerAndRepoAndRef.Input): Promise<patchByOwnerAndRepoAndRef.Output>;
export declare namespace patchByOwnerAndRepoAndRef {
    type Headers = IApiReposGitRefs.PatchHeader;
    type Input = body;
    type Output = git_minus_ref;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/git/refs/:ref";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, ref: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => git_minus_ref;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string, body: patchByOwnerAndRepoAndRef.Input) => Output;
}
/**
 * Delete a reference.
 * Deletes the provided reference.
 *
 * @tag git
 * @path repos/:owner/:repo/git/refs/:ref
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRef(connection: IConnection<eraseByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRef {
    type Headers = IApiReposGitRefs.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/git/refs/:ref";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, ref: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRef.Headers>, owner: string, repo: string, ref: string) => void;
}
