import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposIssuesCommentsReactions } from "../../../../../structures/IApiReposIssuesCommentsReactions";
import { body } from "../../../../../structures/body";
import { reaction } from "../../../../../structures/reaction";
/**
 * List reactions for an issue comment.
 * List the reactions to an [issue comment](https://docs.github.com/rest/issues/comments#get-an-issue-comment).
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/comments/:comment_id/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndComment_id(connection: IConnection<getByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, query: getByOwnerAndRepoAndComment_id.Query): Promise<getByOwnerAndRepoAndComment_id.Output>;
export declare namespace getByOwnerAndRepoAndComment_id {
    type Headers = IApiReposIssuesCommentsReactions.GetHeader;
    type Query = IApiReposIssuesCommentsReactions.GetQuery;
    type Output = reaction[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/issues/comments/:comment_id/reactions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string, query: getByOwnerAndRepoAndComment_id.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, query: getByOwnerAndRepoAndComment_id.Query) => Output;
}
/**
 * Create reaction for an issue comment.
 * Create a reaction to an [issue comment](https://docs.github.com/rest/issues/comments#get-an-issue-comment). A response with an HTTP `200` status means that you already added the reaction type to this issue comment.
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/comments/:comment_id/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndComment_id(connection: IConnection<postByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, body: postByOwnerAndRepoAndComment_id.Input): Promise<postByOwnerAndRepoAndComment_id.Output>;
export declare namespace postByOwnerAndRepoAndComment_id {
    type Headers = IApiReposIssuesCommentsReactions.PostHeader;
    type Input = body;
    type Output = reaction;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/issues/comments/:comment_id/reactions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, body: postByOwnerAndRepoAndComment_id.Input) => Output;
}
/**
 * Delete an issue comment reaction.
 * > [!NOTE]
 * > You can also specify a repository by `repository_id` using the route `DELETE delete /repositories/:repository_id/issues/comments/:comment_id/reactions/:reaction_id`.
 *
 * Delete a reaction to an [issue comment](https://docs.github.com/rest/issues/comments#get-an-issue-comment).
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/comments/:comment_id/reactions/:reaction_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndComment_idAndReaction_id(connection: IConnection<eraseByOwnerAndRepoAndComment_idAndReaction_id.Headers>, owner: string, repo: string, comment_id: string, reaction_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndComment_idAndReaction_id {
    type Headers = IApiReposIssuesCommentsReactions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/issues/comments/:comment_id/reactions/:reaction_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string, reaction_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndComment_idAndReaction_id.Headers>, owner: string, repo: string, comment_id: string, reaction_id: string) => void;
}
