import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPullsCommentsReplies } from "../../../../../structures/IApiReposPullsCommentsReplies";
import { body } from "../../../../../structures/body";
import { pull_minus_request_minus_review_minus_comment } from "../../../../../structures/pull_minus_request_minus_review_minus_comment";
/**
 * Create a reply for a review comment.
 * Creates a reply to a review comment for a pull request. For the `comment_id`, provide the ID of the review comment you are replying to. This must be the ID of a _top-level review comment_, not a reply to that comment. Replies to replies are not supported.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)"
 * and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag pulls
 * @path repos/:owner/:repo/pulls/:pull_number/comments/:comment_id/replies
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndPull_numberAndComment_id(connection: IConnection<postByOwnerAndRepoAndPull_numberAndComment_id.Headers>, owner: string, repo: string, pull_number: string, comment_id: string, body: postByOwnerAndRepoAndPull_numberAndComment_id.Input): Promise<postByOwnerAndRepoAndPull_numberAndComment_id.Output>;
export declare namespace postByOwnerAndRepoAndPull_numberAndComment_id {
    type Headers = IApiReposPullsCommentsReplies.PostHeader;
    type Input = body;
    type Output = pull_minus_request_minus_review_minus_comment;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/pulls/:pull_number/comments/:comment_id/replies";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, pull_number: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => pull_minus_request_minus_review_minus_comment;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndPull_numberAndComment_id.Headers>, owner: string, repo: string, pull_number: string, comment_id: string, body: postByOwnerAndRepoAndPull_numberAndComment_id.Input) => Output;
}
