import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPullsCommits } from "../../../../structures/IApiReposPullsCommits";
import { commit } from "../../../../structures/commit";
/**
 * List commits on a pull request.
 * Lists a maximum of 250 commits for a pull request. To receive a complete
 * commit list for pull requests with more than 250 commits, use the [List commits](https://docs.github.com/rest/commits/commits#list-commits)
 * endpoint.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag pulls
 * @path repos/:owner/:repo/pulls/:pull_number/commits
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndPull_number(connection: IConnection<getByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string): Promise<getByOwnerAndRepoAndPull_number.Output>;
export declare namespace getByOwnerAndRepoAndPull_number {
    type Headers = IApiReposPullsCommits.GetHeader;
    type Output = commit[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/pulls/:pull_number/commits";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, pull_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string) => Output;
}
