import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPullsMerge } from "../../../../structures/IApiReposPullsMerge";
import { body } from "../../../../structures/body";
import { pull_minus_request_minus_merge_minus_result } from "../../../../structures/pull_minus_request_minus_merge_minus_result";
/**
 * Check if a pull request has been merged.
 * Checks if a pull request has been merged into the base branch. The HTTP status of the response indicates whether or not the pull request has been merged; the response body is empty.
 *
 * @tag pulls
 * @path repos/:owner/:repo/pulls/:pull_number/merge
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndPull_number(connection: IConnection<getByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string): Promise<void>;
export declare namespace getByOwnerAndRepoAndPull_number {
    type Headers = IApiReposPullsMerge.GetHeader;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/pulls/:pull_number/merge";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, pull_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string) => void;
}
/**
 * Merge a pull request.
 * Merges a pull request into the base branch.
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * @tag pulls
 * @path repos/:owner/:repo/pulls/:pull_number/merge
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndPull_number(connection: IConnection<putByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string, body: putByOwnerAndRepoAndPull_number.Input): Promise<putByOwnerAndRepoAndPull_number.Output>;
export declare namespace putByOwnerAndRepoAndPull_number {
    type Headers = IApiReposPullsMerge.PutHeader;
    type Input = body;
    type Output = pull_minus_request_minus_merge_minus_result;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/pulls/:pull_number/merge";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, pull_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => pull_minus_request_minus_merge_minus_result;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndPull_number.Headers>, owner: string, repo: string, pull_number: string, body: putByOwnerAndRepoAndPull_number.Input) => Output;
}
