import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposReleasesAssets } from "../../../../structures/IApiReposReleasesAssets";
import { body } from "../../../../structures/body";
import { release_minus_asset } from "../../../../structures/release_minus_asset";
/**
 * Get a release asset.
 * To download the asset's binary content, set the `Accept` header of the request to [`application/octet-stream`](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types). The API will either redirect the client to the location, or stream it directly if possible. API clients should handle both a `200` or `302` response.
 *
 * @tag repos
 * @path repos/:owner/:repo/releases/assets/:asset_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndAsset_id(connection: IConnection<getByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string): Promise<getByOwnerAndRepoAndAsset_id.Output>;
export declare namespace getByOwnerAndRepoAndAsset_id {
    type Headers = IApiReposReleasesAssets.GetHeader;
    type Output = release_minus_asset;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/releases/assets/:asset_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, asset_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release_minus_asset;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string) => Output;
}
/**
 * Update a release asset.
 * Users with push access to the repository can edit a release asset.
 *
 * @tag repos
 * @path repos/:owner/:repo/releases/assets/:asset_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndAsset_id(connection: IConnection<patchByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string, body: patchByOwnerAndRepoAndAsset_id.Input): Promise<patchByOwnerAndRepoAndAsset_id.Output>;
export declare namespace patchByOwnerAndRepoAndAsset_id {
    type Headers = IApiReposReleasesAssets.PatchHeader;
    type Input = body;
    type Output = release_minus_asset;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/releases/assets/:asset_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, asset_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release_minus_asset;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string, body: patchByOwnerAndRepoAndAsset_id.Input) => Output;
}
/**
 * @tag repos
 * @path repos/:owner/:repo/releases/assets/:asset_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndAsset_id(connection: IConnection<eraseByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndAsset_id {
    type Headers = IApiReposReleasesAssets.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/releases/assets/:asset_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, asset_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndAsset_id.Headers>, owner: string, repo: string, asset_id: string) => void;
}
/**
 * @tag repos
 * @path repos/:owner/:repo/releases/:release_id/assets
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRelease_id(connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string): Promise<getByOwnerAndRepoAndRelease_id.Output>;
export declare namespace getByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleasesAssets.GetHeader;
    type Output = release_minus_asset[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/releases/:release_id/assets";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release_minus_asset[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string) => Output;
}
