import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposReleases } from "../../../structures/IApiReposReleases";
import { body } from "../../../structures/body";
import { release } from "../../../structures/release";
export * as assets from "./assets";
export * as generate_notes from "./generate_notes";
export * as latest from "./latest";
export * as tags from "./tags";
export * as reactions from "./reactions";
/**
 * List releases.
 * This returns a list of releases, which does not include regular Git tags that have not been associated with a release. To get a list of Git tags, use the [Repository Tags API](https://docs.github.com/rest/repos/repos#list-repository-tags).
 *
 * Information about published releases are available to everyone. Only users with push access will receive listings for draft releases.
 *
 * @tag repos
 * @path repos/:owner/:repo/releases
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposReleases.GetHeader;
    type Output = release[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/releases";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create a release.
 * Users with push access to the repository can create a release.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * @tag repos
 * @path repos/:owner/:repo/releases
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposReleases.PostHeader;
    type Input = body;
    type Output = release;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/releases";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a release.
 * Gets a public release with the specified release ID.
 *
 * > [!NOTE]
 * > This returns an `upload_url` key corresponding to the endpoint for uploading release assets. This key is a hypermedia resource. For more information, see "[Getting started with the REST API](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#hypermedia)."
 *
 * @tag repos
 * @path repos/:owner/:repo/releases/:release_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRelease_id(connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string): Promise<getByOwnerAndRepoAndRelease_id.Output>;
export declare namespace getByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleases.GetHeader;
    type Output = release;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/releases/:release_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string) => Output;
}
/**
 * Update a release.
 * Users with push access to the repository can edit a release.
 *
 * @tag repos
 * @path repos/:owner/:repo/releases/:release_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndRelease_id(connection: IConnection<patchByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, body: patchByOwnerAndRepoAndRelease_id.Input): Promise<patchByOwnerAndRepoAndRelease_id.Output>;
export declare namespace patchByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleases.PatchHeader;
    type Input = body;
    type Output = release;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/releases/:release_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => release;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, body: patchByOwnerAndRepoAndRelease_id.Input) => Output;
}
/**
 * Delete a release.
 * Users with push access to the repository can delete a release.
 *
 * @tag repos
 * @path repos/:owner/:repo/releases/:release_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRelease_id(connection: IConnection<eraseByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleases.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/releases/:release_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string) => void;
}
