import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiSearchLabels } from "../../../structures/IApiSearchLabels";
import { response } from "../../../structures/response";
/**
 * Search labels.
 * Find labels in a repository with names or descriptions that match search keywords. Returns up to 100 results [per page](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api).
 *
 * When searching for labels, you can get text match metadata for the label **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/search/search#text-match-metadata).
 *
 * For example, if you want to find labels in the `linguist` repository that match `bug`, `defect`, or `enhancement`. Your query might look like this:
 *
 * `q=bug+defect+enhancement&repository_id=64778136`
 *
 * The labels that best match the query appear first in the search results.
 *
 * @tag search
 * @path search/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiSearchLabels.GetHeader;
    type Query = IApiSearchLabels.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/search/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
