import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiSearchTopics } from "../../../structures/IApiSearchTopics";
import { response } from "../../../structures/response";
/**
 * Search topics.
 * Find topics via various criteria. Results are sorted by best match. This method returns up to 100 results [per page](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api). See "[Searching topics](https://docs.github.com/articles/searching-topics/)" for a detailed list of qualifiers.
 *
 * When searching for topics, you can get text match metadata for the topic's **short\_description**, **description**, **name**, or **display\_name** field when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/search/search#text-match-metadata).
 *
 * For example, if you want to search for topics related to Ruby that are featured on https://github.com/topics. Your query might look like this:
 *
 * `q=ruby+is:featured`
 *
 * This query searches for topics with the keyword `ruby` and limits the results to find only topics that are featured. The topics that are the best match for the query appear first in the search results.
 *
 * @tag search
 * @path search/topics
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiSearchTopics.GetHeader;
    type Query = IApiSearchTopics.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/search/topics";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
