import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiTeamsDiscussions } from "../../../structures/IApiTeamsDiscussions";
import { body } from "../../../structures/body";
import { team_minus_discussion } from "../../../structures/team_minus_discussion";
export * as comments from "./comments";
export * as reactions from "./reactions";
/**
 * List discussions (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List discussions`](https://docs.github.com/rest/teams/discussions#list-discussions) endpoint.
 *
 * List all discussions on a team's page.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByTeam_id(connection: IConnection<getByTeam_id.Headers>, team_id: string): Promise<getByTeam_id.Output>;
export declare namespace getByTeam_id {
    type Headers = IApiTeamsDiscussions.GetHeader;
    type Output = team_minus_discussion[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/teams/:team_id/discussions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion[];
    const simulate: (connection: IConnection<getByTeam_id.Headers>, team_id: string) => Output;
}
/**
 * Create a discussion (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Create a discussion`](https://docs.github.com/rest/teams/discussions#create-a-discussion) endpoint.
 *
 * Creates a new discussion post on a team's page.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByTeam_id(connection: IConnection<postByTeam_id.Headers>, team_id: string, body: postByTeam_id.Input): Promise<postByTeam_id.Output>;
export declare namespace postByTeam_id {
    type Headers = IApiTeamsDiscussions.PostHeader;
    type Input = body;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/teams/:team_id/discussions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<postByTeam_id.Headers>, team_id: string, body: postByTeam_id.Input) => Output;
}
/**
 * Get a discussion (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get a discussion](https://docs.github.com/rest/teams/discussions#get-a-discussion) endpoint.
 *
 * Get a specific discussion on a team's page.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByTeam_idAndDiscussion_number(connection: IConnection<getByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string): Promise<getByTeam_idAndDiscussion_number.Output>;
export declare namespace getByTeam_idAndDiscussion_number {
    type Headers = IApiTeamsDiscussions.GetHeader;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/teams/:team_id/discussions/:discussion_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<getByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string) => Output;
}
/**
 * Update a discussion (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Update a discussion](https://docs.github.com/rest/teams/discussions#update-a-discussion) endpoint.
 *
 * Edits the title and body text of a discussion post. Only the parameters you provide are updated.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByTeam_idAndDiscussion_number(connection: IConnection<patchByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string, body: patchByTeam_idAndDiscussion_number.Input): Promise<patchByTeam_idAndDiscussion_number.Output>;
export declare namespace patchByTeam_idAndDiscussion_number {
    type Headers = IApiTeamsDiscussions.PatchHeader;
    type Input = body;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/teams/:team_id/discussions/:discussion_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<patchByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string, body: patchByTeam_idAndDiscussion_number.Input) => Output;
}
/**
 * Delete a discussion (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Delete a discussion`](https://docs.github.com/rest/teams/discussions#delete-a-discussion) endpoint.
 *
 * Delete a discussion from a team's page.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByTeam_idAndDiscussion_number(connection: IConnection<eraseByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string): Promise<void>;
export declare namespace eraseByTeam_idAndDiscussion_number {
    type Headers = IApiTeamsDiscussions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/teams/:team_id/discussions/:discussion_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string) => void;
}
