import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiTeamsMemberships } from "../../../structures/IApiTeamsMemberships";
import { body } from "../../../structures/body";
import { team_minus_membership } from "../../../structures/team_minus_membership";
/**
 * Get team membership for a user (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get team membership for a user](https://docs.github.com/rest/teams/members#get-team-membership-for-a-user) endpoint.
 *
 * Team members will include the members of child teams.
 *
 * To get a user's membership with a team, the team must be visible to the authenticated user.
 *
 * **Note:**
 * The response contains the `state` of the membership and the member's `role`.
 *
 * The `role` for organization owners is set to `maintainer`. For more information about `maintainer` roles, see [Create a team](https://docs.github.com/rest/teams/teams#create-a-team).
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByTeam_idAndUsername(connection: IConnection<getByTeam_idAndUsername.Headers>, team_id: string, username: string): Promise<getByTeam_idAndUsername.Output>;
export declare namespace getByTeam_idAndUsername {
    type Headers = IApiTeamsMemberships.GetHeader;
    type Output = team_minus_membership;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/teams/:team_id/memberships/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_membership;
    const simulate: (connection: IConnection<getByTeam_idAndUsername.Headers>, team_id: string, username: string) => Output;
}
/**
 * Add or update team membership for a user (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Add or update team membership for a user](https://docs.github.com/rest/teams/members#add-or-update-team-membership-for-a-user) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * If the user is already a member of the team's organization, this endpoint will add the user to the team. To add a membership between an organization member and a team, the authenticated user must be an organization owner or a team maintainer.
 *
 * > [!NOTE]
 * > When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * If the user is unaffiliated with the team's organization, this endpoint will send an invitation to the user via email. This newly-created membership will be in the "pending" state until the user accepts the invitation, at which point the membership will transition to the "active" state and the user will be added as a member of the team. To add a membership between an unaffiliated user and a team, the authenticated user must be an organization owner.
 *
 * If the user is already a member of the team, this endpoint will update the role of the team member's role. To update the membership of a team member, the authenticated user must be an organization owner or a team maintainer.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByTeam_idAndUsername(connection: IConnection<putByTeam_idAndUsername.Headers>, team_id: string, username: string, body: putByTeam_idAndUsername.Input): Promise<putByTeam_idAndUsername.Output>;
export declare namespace putByTeam_idAndUsername {
    type Headers = IApiTeamsMemberships.PutHeader;
    type Input = body;
    type Output = team_minus_membership;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/teams/:team_id/memberships/:username";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_membership;
    const simulate: (connection: IConnection<putByTeam_idAndUsername.Headers>, team_id: string, username: string, body: putByTeam_idAndUsername.Input) => Output;
}
/**
 * Remove team membership for a user (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Remove team membership for a user](https://docs.github.com/rest/teams/members#remove-team-membership-for-a-user) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To remove a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with. Removing team membership does not delete the user, it just removes their membership from the team.
 *
 * > [!NOTE]
 * > When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/memberships/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByTeam_idAndUsername(connection: IConnection<eraseByTeam_idAndUsername.Headers>, team_id: string, username: string): Promise<void>;
export declare namespace eraseByTeam_idAndUsername {
    type Headers = IApiTeamsMemberships.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/teams/:team_id/memberships/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByTeam_idAndUsername.Headers>, team_id: string, username: string) => void;
}
