import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserBlocks } from "../../../structures/IApiUserBlocks";
import { simple_minus_user } from "../../../structures/simple_minus_user";
/**
 * List users blocked by the authenticated user.
 * List the users you've blocked on your personal account.
 *
 * @tag users
 * @path user/blocks
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserBlocks.GetHeader;
    type Output = simple_minus_user[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/blocks";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => simple_minus_user[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Check if a user is blocked by the authenticated user.
 * Returns a 204 if the given user is blocked by the authenticated user. Returns a 404 if the given user is not blocked by the authenticated user, or if the given user account has been identified as spam by GitHub.
 *
 * @tag users
 * @path user/blocks/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsername(connection: IConnection<getByUsername.Headers>, username: string): Promise<void>;
export declare namespace getByUsername {
    type Headers = IApiUserBlocks.GetHeader;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/blocks/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<getByUsername.Headers>, username: string) => void;
}
/**
 * Block a user.
 * Blocks the given user and returns a 204. If the authenticated user cannot block the given user a 422 is returned.
 *
 * @tag users
 * @path user/blocks/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByUsername(connection: IConnection<putByUsername.Headers>, username: string): Promise<void>;
export declare namespace putByUsername {
    type Headers = IApiUserBlocks.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/user/blocks/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByUsername.Headers>, username: string) => void;
}
/**
 * Unblock a user.
 * Unblocks the given user and returns a 204.
 *
 * @tag users
 * @path user/blocks/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByUsername(connection: IConnection<eraseByUsername.Headers>, username: string): Promise<void>;
export declare namespace eraseByUsername {
    type Headers = IApiUserBlocks.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/blocks/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByUsername.Headers>, username: string) => void;
}
