import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserCodespaces } from "../../../structures/IApiUserCodespaces";
import { body } from "../../../structures/body";
import { codespace } from "../../../structures/codespace";
import { response } from "../../../structures/response";
export * as secrets from "./secrets";
export * as exports from "./exports";
export * as machines from "./machines";
export * as publish from "./publish";
export * as start from "./start";
export * as stop from "./stop";
/**
 * List codespaces for the authenticated user.
 * Lists the authenticated user's codespaces.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserCodespaces.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Create a codespace for the authenticated user.
 * Creates a new codespace, owned by the authenticated user.
 *
 * This endpoint requires either a `repository_id` OR a `pull_request` but not both.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = codespace;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/codespaces";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespace;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Get a codespace for the authenticated user.
 * Gets information about a user's codespace.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/:codespace_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByCodespace_name(connection: IConnection<getByCodespace_name.Headers>, codespace_name: string): Promise<getByCodespace_name.Output>;
export declare namespace getByCodespace_name {
    type Headers = IApiUserCodespaces.GetHeader;
    type Output = codespace;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces/:codespace_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (codespace_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespace;
    const simulate: (connection: IConnection<getByCodespace_name.Headers>, codespace_name: string) => Output;
}
/**
 * Update a codespace for the authenticated user.
 * Updates a codespace owned by the authenticated user. Currently only the codespace's machine type and recent folders can be modified using this endpoint.
 *
 * If you specify a new machine type it will be applied the next time your codespace is started.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/:codespace_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByCodespace_name(connection: IConnection<patchByCodespace_name.Headers>, codespace_name: string, body: patchByCodespace_name.Input): Promise<patchByCodespace_name.Output>;
export declare namespace patchByCodespace_name {
    type Headers = IApiUserCodespaces.PatchHeader;
    type Input = body;
    type Output = codespace;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/user/codespaces/:codespace_name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (codespace_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespace;
    const simulate: (connection: IConnection<patchByCodespace_name.Headers>, codespace_name: string, body: patchByCodespace_name.Input) => Output;
}
/**
 * Delete a codespace for the authenticated user.
 * Deletes a user's codespace.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/:codespace_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByCodespace_name(connection: IConnection<eraseByCodespace_name.Headers>, codespace_name: string): Promise<void>;
export declare namespace eraseByCodespace_name {
    type Headers = IApiUserCodespaces.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/codespaces/:codespace_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (codespace_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByCodespace_name.Headers>, codespace_name: string) => void;
}
