import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserCodespacesSecrets } from "../../../../structures/IApiUserCodespacesSecrets";
import { body } from "../../../../structures/body";
import { codespaces_minus_secret } from "../../../../structures/codespaces_minus_secret";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { response } from "../../../../structures/response";
export * as public_key from "./public_key";
export * as repositories from "./repositories";
/**
 * List secrets for the authenticated user.
 * Lists all development environment secrets available for a user's codespaces without revealing their
 * encrypted values.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserCodespacesSecrets.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces/secrets";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Get a secret for the authenticated user.
 * Gets a development environment secret available to a user's codespaces without revealing its encrypted value.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getBySecret_name(connection: IConnection<getBySecret_name.Headers>, secret_name: string): Promise<getBySecret_name.Output>;
export declare namespace getBySecret_name {
    type Headers = IApiUserCodespacesSecrets.GetHeader;
    type Output = codespaces_minus_secret;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespaces_minus_secret;
    const simulate: (connection: IConnection<getBySecret_name.Headers>, secret_name: string) => Output;
}
/**
 * Create or update a secret for the authenticated user.
 * Creates or updates a development environment secret for a user's codespace with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). For more information, see "[Encrypting secrets for the REST API](https://docs.github.com/rest/guides/encrypting-secrets-for-the-rest-api)."
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putBySecret_name(connection: IConnection<putBySecret_name.Headers>, secret_name: string, body: putBySecret_name.Input): Promise<putBySecret_name.Output>;
export declare namespace putBySecret_name {
    type Headers = IApiUserCodespacesSecrets.PutHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/user/codespaces/secrets/:secret_name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<putBySecret_name.Headers>, secret_name: string, body: putBySecret_name.Input) => Output;
}
/**
 * Delete a secret for the authenticated user.
 * Deletes a development environment secret from a user's codespaces using the secret name. Deleting the secret will remove access from all codespaces that were allowed to access the secret.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseBySecret_name(connection: IConnection<eraseBySecret_name.Headers>, secret_name: string): Promise<void>;
export declare namespace eraseBySecret_name {
    type Headers = IApiUserCodespacesSecrets.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/codespaces/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseBySecret_name.Headers>, secret_name: string) => void;
}
