import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserEmails } from "../../../structures/IApiUserEmails";
import { body } from "../../../structures/body";
import { email } from "../../../structures/email";
/**
 * List email addresses for the authenticated user.
 * Lists all of your email addresses, and specifies which one is visible
 * to the public.
 *
 * OAuth app tokens and personal access tokens (classic) need the `user:email` scope to use this endpoint.
 *
 * @tag users
 * @path user/emails
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserEmails.GetHeader;
    type Output = email[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/emails";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => email[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Add an email address for the authenticated user.
 * OAuth app tokens and personal access tokens (classic) need the `user` scope to use this endpoint.
 *
 * @tag users
 * @path user/emails
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = email[];
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/emails";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => email[];
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Delete an email address for the authenticated user.
 * OAuth app tokens and personal access tokens (classic) need the `user` scope to use this endpoint.
 *
 * @tag users
 * @path user/emails
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function erase(connection: IConnection, body: erase.Input): Promise<void>;
export declare namespace erase {
    type Input = body;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/emails";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection, body: erase.Input) => void;
}
