import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserKeys } from "../../../structures/IApiUserKeys";
import { body } from "../../../structures/body";
import { key } from "../../../structures/key";
/**
 * List public SSH keys for the authenticated user.
 * Lists the public SSH keys for the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:public_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserKeys.GetHeader;
    type Output = key[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/keys";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => key[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Create a public SSH key for the authenticated user.
 * Adds a public SSH key to the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:gpg_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = key;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/keys";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => key;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Get a public SSH key for the authenticated user.
 * View extended details for a single public SSH key.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:public_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/keys/:key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByKey_id(connection: IConnection<getByKey_id.Headers>, key_id: string): Promise<getByKey_id.Output>;
export declare namespace getByKey_id {
    type Headers = IApiUserKeys.GetHeader;
    type Output = key;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/keys/:key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => key;
    const simulate: (connection: IConnection<getByKey_id.Headers>, key_id: string) => Output;
}
/**
 * Delete a public SSH key for the authenticated user.
 * Removes a public SSH key from the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:public_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/keys/:key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByKey_id(connection: IConnection<eraseByKey_id.Headers>, key_id: string): Promise<void>;
export declare namespace eraseByKey_id {
    type Headers = IApiUserKeys.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/keys/:key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByKey_id.Headers>, key_id: string) => void;
}
