import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserMigrationsArchive } from "../../../../structures/IApiUserMigrationsArchive";
/**
 * Download a user migration archive.
 * Fetches the URL to download the migration archive as a `tar.gz` file. Depending on the resources your repository uses, the migration archive can contain JSON files with data for these objects:
 *
 * *   attachments
 * *   bases
 * *   commit\_comments
 * *   issue\_comments
 * *   issue\_events
 * *   issues
 * *   milestones
 * *   organizations
 * *   projects
 * *   protected\_branches
 * *   pull\_request\_reviews
 * *   pull\_requests
 * *   releases
 * *   repositories
 * *   review\_comments
 * *   schema
 * *   users
 *
 * The archive will also contain an `attachments` directory that includes all attachment files uploaded to GitHub.com and a `repositories` directory that contains the repository's Git data.
 *
 * @tag migrations
 * @path user/migrations/:migration_id/archive
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByMigration_id(connection: IConnection<getByMigration_id.Headers>, migration_id: string): Promise<void>;
export declare namespace getByMigration_id {
    type Headers = IApiUserMigrationsArchive.GetHeader;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/migrations/:migration_id/archive";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (migration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<getByMigration_id.Headers>, migration_id: string) => void;
}
/**
 * Delete a user migration archive.
 * Deletes a previous migration archive. Downloadable migration archives are automatically deleted after seven days. Migration metadata, which is returned in the [List user migrations](https://docs.github.com/rest/migrations/users#list-user-migrations) and [Get a user migration status](https://docs.github.com/rest/migrations/users#get-a-user-migration-status) endpoints, will continue to be available even after an archive is deleted.
 *
 * @tag migrations
 * @path user/migrations/:migration_id/archive
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByMigration_id(connection: IConnection<eraseByMigration_id.Headers>, migration_id: string): Promise<void>;
export declare namespace eraseByMigration_id {
    type Headers = IApiUserMigrationsArchive.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/migrations/:migration_id/archive";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (migration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByMigration_id.Headers>, migration_id: string) => void;
}
