import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserMigrations } from "../../../structures/IApiUserMigrations";
import { body } from "../../../structures/body";
import { migration } from "../../../structures/migration";
export * as archive from "./archive";
export * as repos from "./repos";
export * as repositories from "./repositories";
/**
 * List user migrations.
 * Lists all migrations a user has started.
 *
 * @tag migrations
 * @path user/migrations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserMigrations.GetHeader;
    type Output = migration[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/migrations";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Start a user migration.
 * Initiates the generation of a user migration archive.
 *
 * @tag migrations
 * @path user/migrations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = migration;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/migrations";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Get a user migration status.
 * Fetches a single user migration. The response includes the `state` of the migration, which can be one of the following values:
 *
 * *   `pending` - the migration hasn't started yet.
 * *   `exporting` - the migration is in progress.
 * *   `exported` - the migration finished successfully.
 * *   `failed` - the migration failed.
 *
 * Once the migration has been `exported` you can [download the migration archive](https://docs.github.com/rest/migrations/users#download-a-user-migration-archive).
 *
 * @tag migrations
 * @path user/migrations/:migration_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByMigration_id(connection: IConnection<getByMigration_id.Headers>, migration_id: string, query: getByMigration_id.Query): Promise<getByMigration_id.Output>;
export declare namespace getByMigration_id {
    type Headers = IApiUserMigrations.GetHeader;
    type Query = IApiUserMigrations.GetQuery;
    type Output = migration;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/migrations/:migration_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (migration_id: string, query: getByMigration_id.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration;
    const simulate: (connection: IConnection<getByMigration_id.Headers>, migration_id: string, query: getByMigration_id.Query) => Output;
}
