import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserPackages } from "../../../structures/IApiUserPackages";
import { packages } from "../../../structures/package";
export * as restore from "./restore";
export * as versions from "./versions";
/**
 * List packages for the authenticated user's namespace.
 * Lists packages owned by the authenticated user within the user's namespace.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path user/packages
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserPackages.GetHeader;
    type Query = IApiUserPackages.GetQuery;
    type Output = packages[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/packages";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages[];
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
/**
 * Get a package for the authenticated user.
 * Gets a specific package for a package owned by the authenticated user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path user/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByPackage_typeAndPackage_name(connection: IConnection<getByPackage_typeAndPackage_name.Headers>, package_type: string, package_name: string): Promise<getByPackage_typeAndPackage_name.Output>;
export declare namespace getByPackage_typeAndPackage_name {
    type Headers = IApiUserPackages.GetHeader;
    type Output = packages;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages;
    const simulate: (connection: IConnection<getByPackage_typeAndPackage_name.Headers>, package_type: string, package_name: string) => Output;
}
/**
 * Delete a package for the authenticated user.
 * Deletes a package owned by the authenticated user. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` and `delete:packages` scopes to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, `repo` scope is also required. For the list these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path user/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByPackage_typeAndPackage_name(connection: IConnection<eraseByPackage_typeAndPackage_name.Headers>, package_type: string, package_name: string): Promise<void>;
export declare namespace eraseByPackage_typeAndPackage_name {
    type Headers = IApiUserPackages.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByPackage_typeAndPackage_name.Headers>, package_type: string, package_name: string) => void;
}
