import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserSshSigningKeys } from "../../../structures/IApiUserSshSigningKeys";
import { body } from "../../../structures/body";
import { ssh_minus_signing_minus_key } from "../../../structures/ssh_minus_signing_minus_key";
/**
 * List SSH signing keys for the authenticated user.
 * Lists the SSH signing keys for the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:ssh_signing_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/ssh_signing_keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserSshSigningKeys.GetHeader;
    type Output = ssh_minus_signing_minus_key[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/ssh_signing_keys";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => ssh_minus_signing_minus_key[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Create a SSH signing key for the authenticated user.
 * Creates an SSH signing key for the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:ssh_signing_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/ssh_signing_keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = ssh_minus_signing_minus_key;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/ssh_signing_keys";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => ssh_minus_signing_minus_key;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Get an SSH signing key for the authenticated user.
 * Gets extended details for an SSH signing key.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:ssh_signing_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/ssh_signing_keys/:ssh_signing_key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getBySsh_signing_key_id(connection: IConnection<getBySsh_signing_key_id.Headers>, ssh_signing_key_id: string): Promise<getBySsh_signing_key_id.Output>;
export declare namespace getBySsh_signing_key_id {
    type Headers = IApiUserSshSigningKeys.GetHeader;
    type Output = ssh_minus_signing_minus_key;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/ssh_signing_keys/:ssh_signing_key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (ssh_signing_key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => ssh_minus_signing_minus_key;
    const simulate: (connection: IConnection<getBySsh_signing_key_id.Headers>, ssh_signing_key_id: string) => Output;
}
/**
 * Delete an SSH signing key for the authenticated user.
 * Deletes an SSH signing key from the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:ssh_signing_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/ssh_signing_keys/:ssh_signing_key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseBySsh_signing_key_id(connection: IConnection<eraseBySsh_signing_key_id.Headers>, ssh_signing_key_id: string): Promise<void>;
export declare namespace eraseBySsh_signing_key_id {
    type Headers = IApiUserSshSigningKeys.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/ssh_signing_keys/:ssh_signing_key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (ssh_signing_key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseBySsh_signing_key_id.Headers>, ssh_signing_key_id: string) => void;
}
