import { tags } from "typia";
export declare namespace IApiEnterprisesSecretScanningAlerts {
    type GetHeader = {
        /**
         * The slug version of the enterprise name. You can also substitute this value with the enterprise id.
         */
        enterprise: string;
        /**
         * A comma-separated list of secret types to return. By default all secret types are returned.
         * See "[Supported secret scanning patterns](https://docs.github.com/code-security/secret-scanning/introduction/supported-secret-scanning-patterns#supported-secrets)"
         * for a complete list of secret types.
         */
        secret_type?: string;
        /**
         * A comma-separated list of resolutions. Only secret scanning alerts with one of these resolutions are listed. Valid resolutions are `false_positive`, `wont_fix`, `revoked`, `pattern_edited`, `pattern_deleted` or `used_in_tests`.
         */
        resolution?: string;
        /**
         * The number of results per page (max 100). For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        per_page?: number & tags.Type<"int32"> & tags.Default<30>;
        /**
         * A cursor, as given in the [Link header](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api#using-link-headers). If specified, the query only searches for results before this cursor. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        before?: string;
        /**
         * A cursor, as given in the [Link header](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api#using-link-headers). If specified, the query only searches for results after this cursor. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        after?: string;
        /**
         * A comma-separated list of validities that, when present, will return alerts that match the validities in this list. Valid options are `active`, `inactive`, and `unknown`.
         */
        validity?: string;
    };
}
