import { tags } from "typia";
export declare namespace IApiNotifications {
    type GetHeader = {
        /**
         * If `true`, show notifications marked as read.
         */
        all?: boolean;
        /**
         * If `true`, only shows notifications in which the user is directly participating or mentioned.
         */
        participating?: boolean;
        /**
         * Only show results that were last updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
         */
        since?: string & tags.Format<"date-time">;
        /**
         * Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
         */
        before?: string & tags.Format<"date-time">;
        /**
         * The page number of the results to fetch. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        page?: number & tags.Type<"int32"> & tags.Default<1>;
    };
    type GetQuery = {
        /**
         * The number of results per page (max 50). For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        per_page?: number & tags.Type<"int32"> & tags.Default<50>;
    };
}
