import { tags } from "typia";
export declare namespace IApiReposCommits {
    type GetHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The page number of the results to fetch. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        page?: number & tags.Type<"int32"> & tags.Default<1>;
        /**
         * The number of results per page (max 100). For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        per_page?: number & tags.Type<"int32"> & tags.Default<30>;
        /**
         * The commit reference. Can be a commit SHA, branch name (`heads/BRANCH_NAME`), or tag name (`tags/TAG_NAME`). For more information, see "[Git References](https://git-scm.com/book/en/v2/Git-Internals-Git-References)" in the Git documentation.
         */
        ref: string;
    };
    type GetQuery = {
        /**
         * SHA or branch to start listing commits from. Default: the repository’s default branch (usually `main`).
         */
        sha?: string;
        /**
         * Only commits containing this file path will be returned.
         */
        path?: string;
        /**
         * GitHub username or email address to use to filter by commit author.
         */
        author?: string;
        /**
         * GitHub username or email address to use to filter by commit committer.
         */
        committer?: string;
        /**
         * Only show results that were last updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`. Due to limitations of Git, timestamps must be between 1970-01-01 and 2099-12-31 (inclusive) or unexpected results may be returned.
         */
        since?: string & tags.Format<"date-time">;
        /**
         * Only commits before this date will be returned. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`. Due to limitations of Git, timestamps must be between 1970-01-01 and 2099-12-31 (inclusive) or unexpected results may be returned.
         */
        until?: string & tags.Format<"date-time">;
    };
}
