import { tags } from "typia";
import { nullable_minus_simple_minus_user } from "./nullable_minus_simple_minus_user";
/**
 * GitHub apps are a new way to extend GitHub. They can be installed directly on organizations and user accounts and granted access to specific repositories. They come with granular permissions and built-in webhooks. GitHub apps are first class actors within GitHub.
 *
 * @title GitHub app
 */
export type integration = {
    /**
     * Unique identifier of the GitHub app
     */
    id: number & tags.Type<"int32"> & tags.JsonSchemaPlugin<{
        example: 37;
    }>;
    /**
     * The slug name of the GitHub app
     */
    slug?: string & tags.JsonSchemaPlugin<{
        example: "probot-owners";
    }>;
    node_id: string & tags.JsonSchemaPlugin<{
        example: "MDExOkludGVncmF0aW9uMQ==";
    }>;
    client_id?: string & tags.JsonSchemaPlugin<{
        example: '"Iv1.25b5d1e65ffc4022"';
    }>;
    owner: nullable_minus_simple_minus_user;
    /**
     * The name of the GitHub app
     */
    name: string & tags.JsonSchemaPlugin<{
        example: "Probot Owners";
    }>;
    description: (string & tags.JsonSchemaPlugin<{
        example: "The description of the app.";
    }>) | null;
    external_url: string & tags.Format<"uri"> & tags.JsonSchemaPlugin<{
        example: "https://example.com";
    }>;
    html_url: string & tags.Format<"uri"> & tags.JsonSchemaPlugin<{
        example: "https://github.com/apps/super-ci";
    }>;
    created_at: string & tags.Format<"date-time"> & tags.JsonSchemaPlugin<{
        example: "2017-07-08T16:18:44-04:00";
    }>;
    updated_at: string & tags.Format<"date-time"> & tags.JsonSchemaPlugin<{
        example: "2017-07-08T16:18:44-04:00";
    }>;
    /**
     * The set of permissions for the GitHub app
     */
    permissions: {
        [key: string]: string;
    };
    /**
     * The list of events for the GitHub app
     */
    events: string[] & tags.JsonSchemaPlugin<{
        example: ["label", "deployment"];
    }>;
    /**
     * The number of installations associated with the GitHub app
     */
    installations_count?: number & tags.Type<"int32"> & tags.JsonSchemaPlugin<{
        example: 5;
    }>;
    client_secret?: string & tags.JsonSchemaPlugin<{
        example: '"1d4b2097ac622ba702d19de498f005747a8b21d3"';
    }>;
    webhook_secret?: (string & tags.JsonSchemaPlugin<{
        example: '"6fba8f2fc8a7e8f2cca5577eddd82ca7586b3b6b"';
    }>) | null;
    pem?: string & tags.JsonSchemaPlugin<{
        example: '"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEArYxrNYD/iT5CZVpRJu4rBKmmze3PVmT/gCo2ATUvDvZTPTey\\nxcGJ3vvrJXazKk06pN05TN29o98jrYz4cengG3YGsXPNEpKsIrEl8NhbnxapEnM9\\nJCMRe0P5JcPsfZlX6hmiT7136GRWiGOUba2X9+HKh8QJVLG5rM007TBER9/z9mWm\\nrJuNh+m5l320oBQY/Qq3A7wzdEfZw8qm/mIN0FCeoXH1L6B8xXWaAYBwhTEh6SSn\\nZHlO1Xu1JWDmAvBCi0RO5aRSKM8q9QEkvvHP4yweAtK3N8+aAbZ7ovaDhyGz8r6r\\nzhU1b8Uo0Z2ysf503WqzQgIajr7Fry7/kUwpgQIDAQABAoIBADwJp80Ko1xHPZDy\\nfcCKBDfIuPvkmSW6KumbsLMaQv1aGdHDwwTGv3t0ixSay8CGlxMRtRDyZPib6SvQ\\n6OH/lpfpbMdW2ErkksgtoIKBVrDilfrcAvrNZu7NxRNbhCSvN8q0s4ICecjbbVQh\\nnueSdlA6vGXbW58BHMq68uRbHkP+k+mM9U0mDJ1HMch67wlg5GbayVRt63H7R2+r\\nVxcna7B80J/lCEjIYZznawgiTvp3MSanTglqAYi+m1EcSsP14bJIB9vgaxS79kTu\\noiSo93leJbBvuGo8QEiUqTwMw4tDksmkLsoqNKQ1q9P7LZ9DGcujtPy4EZsamSJT\\ny8OJt0ECgYEA2lxOxJsQk2kI325JgKFjo92mQeUObIvPfSNWUIZQDTjniOI6Gv63\\nGLWVFrZcvQBWjMEQraJA9xjPbblV8PtfO87MiJGLWCHFxmPz2dzoedN+2Coxom8m\\nV95CLz8QUShuao6u/RYcvUaZEoYs5bHcTmy5sBK80JyEmafJPtCQVxMCgYEAy3ar\\nZr3yv4xRPEPMat4rseswmuMooSaK3SKub19WFI5IAtB/e7qR1Rj9JhOGcZz+OQrl\\nT78O2OFYlgOIkJPvRMrPpK5V9lslc7tz1FSh3BZMRGq5jSyD7ETSOQ0c8T2O/s7v\\nbeEPbVbDe4mwvM24XByH0GnWveVxaDl51ABD65sCgYB3ZAspUkOA5egVCh8kNpnd\\nSd6SnuQBE3ySRlT2WEnCwP9Ph6oPgn+oAfiPX4xbRqkL8q/k0BdHQ4h+zNwhk7+h\\nWtPYRAP1Xxnc/F+jGjb+DVaIaKGU18MWPg7f+FI6nampl3Q0KvfxwX0GdNhtio8T\\nTj1E+SnFwh56SRQuxSh2gwKBgHKjlIO5NtNSflsUYFM+hyQiPiqnHzddfhSG+/3o\\nm5nNaSmczJesUYreH5San7/YEy2UxAugvP7aSY2MxB+iGsiJ9WD2kZzTUlDZJ7RV\\nUzWsoqBR+eZfVJ2FUWWvy8TpSG6trh4dFxImNtKejCR1TREpSiTV3Zb1dmahK9GV\\nrK9NAoGAbBxRLoC01xfxCTgt5BDiBcFVh4fp5yYKwavJPLzHSpuDOrrI9jDn1oKN\\nonq5sDU1i391zfQvdrbX4Ova48BN+B7p63FocP/MK5tyyBoT8zQEk2+vWDOw7H/Z\\nu5dTCPxTIsoIwUw1I+7yIxqJzLPFgR2gVBwY1ra/8iAqCj+zeBw=\\n-----END RSA PRIVATE KEY-----\\n"';
    }>;
} | null;
