import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPrivateVulnerabilityReporting } from "../../../structures/IApiReposPrivateVulnerabilityReporting";
import { response } from "../../../structures/response";
/**
 * Check if private vulnerability reporting is enabled for a repository.
 * Returns a boolean indicating whether or not private vulnerability reporting is enabled for the repository. For more information, see "[Evaluating the security settings of a repository](https://docs.github.com/code-security/security-advisories/working-with-repository-security-advisories/evaluating-the-security-settings-of-a-repository)".
 *
 * @tag repos
 * @path repos/:owner/:repo/private-vulnerability-reporting
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposPrivateVulnerabilityReporting.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/private-vulnerability-reporting";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Enable private vulnerability reporting for a repository.
 * Enables private vulnerability reporting for a repository. The authenticated user must have admin access to the repository. For more information, see "[Privately reporting a security vulnerability](https://docs.github.com/code-security/security-advisories/guidance-on-reporting-and-writing/privately-reporting-a-security-vulnerability)."
 *
 * @tag repos
 * @path repos/:owner/:repo/private-vulnerability-reporting
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposPrivateVulnerabilityReporting.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/private-vulnerability-reporting";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
/**
 * Disable private vulnerability reporting for a repository.
 * Disables private vulnerability reporting for a repository. The authenticated user must have admin access to the repository. For more information, see "[Privately reporting a security vulnerability](https://docs.github.com/code-security/security-advisories/guidance-on-reporting-and-writing/privately-reporting-a-security-vulnerability)".
 *
 * @tag repos
 * @path repos/:owner/:repo/private-vulnerability-reporting
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepo(connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace eraseByOwnerAndRepo {
    type Headers = IApiReposPrivateVulnerabilityReporting.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/private-vulnerability-reporting";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
