import { tags } from "typia";
import { security_minus_advisory_minus_ecosystems } from "./security_minus_advisory_minus_ecosystems";
/**
 * A vulnerability describing the product and its affected versions within a GitHub Security Advisory.
 */
export type vulnerability = {
    /**
     * The name of the package affected by the vulnerability.
     */
    package: {
        ecosystem: security_minus_advisory_minus_ecosystems;
        /**
         * The unique package name within its ecosystem.
         */
        name: string | null;
    } | null;
    /**
     * The range of the package versions affected by the vulnerability.
     */
    vulnerable_version_range: string | null;
    /**
     * The package version that resolves the vulnerability.
     */
    first_patched_version: string | null;
    /**
     * The functions in the package that are affected by the vulnerability.
     */
    vulnerable_functions: (string[] & tags.JsonSchemaPlugin<{
        readOnly: true;
    }>) | null;
};
